# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations


import proto  # type: ignore


__protobuf__ = proto.module(
    package="google.ads.googleads.v20.enums",
    marshal="google.ads.googleads.v20",
    manifest={
        "AdGroupTypeEnum",
    },
)


class AdGroupTypeEnum(proto.Message):
    r"""Defines types of an ad group, specific to a particular
    campaign channel type. This type drives validations that
    restrict which entities can be added to the ad group.

    """

    class AdGroupType(proto.Enum):
        r"""Enum listing the possible types of an ad group.

        Values:
            UNSPECIFIED (0):
                The type has not been specified.
            UNKNOWN (1):
                The received value is not known in this
                version.
                This is a response-only value.
            SEARCH_STANDARD (2):
                The default ad group type for Search
                campaigns.
            DISPLAY_STANDARD (3):
                The default ad group type for Display
                campaigns.
            SHOPPING_PRODUCT_ADS (4):
                The ad group type for Shopping campaigns
                serving standard product ads.
            HOTEL_ADS (6):
                The default ad group type for Hotel
                campaigns.
            SHOPPING_SMART_ADS (7):
                The type for ad groups in Smart Shopping
                campaigns.
            VIDEO_BUMPER (8):
                Short unskippable in-stream video ads.
            VIDEO_TRUE_VIEW_IN_STREAM (9):
                TrueView (skippable) in-stream video ads.
            VIDEO_TRUE_VIEW_IN_DISPLAY (10):
                TrueView in-display video ads.
            VIDEO_NON_SKIPPABLE_IN_STREAM (11):
                Unskippable in-stream video ads.
            SEARCH_DYNAMIC_ADS (13):
                Ad group type for Dynamic Search Ads ad
                groups.
            SHOPPING_COMPARISON_LISTING_ADS (14):
                The type for ad groups in Shopping Comparison
                Listing campaigns.
            PROMOTED_HOTEL_ADS (15):
                The ad group type for Promoted Hotel ad
                groups.
            VIDEO_RESPONSIVE (16):
                Video responsive ad groups.
            VIDEO_EFFICIENT_REACH (17):
                Video efficient reach ad groups.
            SMART_CAMPAIGN_ADS (18):
                Ad group type for Smart campaigns.
            TRAVEL_ADS (19):
                Ad group type for Travel campaigns.
            YOUTUBE_AUDIO (20):
                Ad group type for YouTube Audio campaigns.
        """

        UNSPECIFIED = 0
        UNKNOWN = 1
        SEARCH_STANDARD = 2
        DISPLAY_STANDARD = 3
        SHOPPING_PRODUCT_ADS = 4
        HOTEL_ADS = 6
        SHOPPING_SMART_ADS = 7
        VIDEO_BUMPER = 8
        VIDEO_TRUE_VIEW_IN_STREAM = 9
        VIDEO_TRUE_VIEW_IN_DISPLAY = 10
        VIDEO_NON_SKIPPABLE_IN_STREAM = 11
        SEARCH_DYNAMIC_ADS = 13
        SHOPPING_COMPARISON_LISTING_ADS = 14
        PROMOTED_HOTEL_ADS = 15
        VIDEO_RESPONSIVE = 16
        VIDEO_EFFICIENT_REACH = 17
        SMART_CAMPAIGN_ADS = 18
        TRAVEL_ADS = 19
        YOUTUBE_AUDIO = 20


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations


import proto  # type: ignore


__protobuf__ = proto.module(
    package="google.ads.googleads.v21.errors",
    marshal="google.ads.googleads.v21",
    manifest={
        "AuthenticationErrorEnum",
    },
)


class AuthenticationErrorEnum(proto.Message):
    r"""Container for enum describing possible authentication errors."""

    class AuthenticationError(proto.Enum):
        r"""Enum describing possible authentication errors.

        Values:
            UNSPECIFIED (0):
                Enum unspecified.
            UNKNOWN (1):
                The received error code is not known in this
                version.
            AUTHENTICATION_ERROR (2):
                Authentication of the request failed.
            CLIENT_CUSTOMER_ID_INVALID (5):
                Client customer ID is not a number.
            CUSTOMER_NOT_FOUND (8):
                No customer found for the provided customer
                ID.
            GOOGLE_ACCOUNT_DELETED (9):
                Client's Google account is deleted.
            GOOGLE_ACCOUNT_COOKIE_INVALID (10):
                Google account login token in the cookie is
                invalid.
            GOOGLE_ACCOUNT_AUTHENTICATION_FAILED (25):
                A problem occurred during Google account
                authentication.
            GOOGLE_ACCOUNT_USER_AND_ADS_USER_MISMATCH (12):
                The user in the Google account login token
                does not match the user ID in the cookie.
            LOGIN_COOKIE_REQUIRED (13):
                Login cookie is required for authentication.
            NOT_ADS_USER (14):
                The Google account that generated the OAuth
                access token is not associated with a Google Ads
                account. Create a new account, or add the Google
                account to an existing Google Ads account.
            OAUTH_TOKEN_INVALID (15):
                OAuth token in the header is not valid.
            OAUTH_TOKEN_EXPIRED (16):
                OAuth token in the header has expired.
            OAUTH_TOKEN_DISABLED (17):
                OAuth token in the header has been disabled.
            OAUTH_TOKEN_REVOKED (18):
                OAuth token in the header has been revoked.
            OAUTH_TOKEN_HEADER_INVALID (19):
                OAuth token HTTP header is malformed.
            LOGIN_COOKIE_INVALID (20):
                Login cookie is not valid.
            USER_ID_INVALID (22):
                User ID in the header is not a valid ID.
            TWO_STEP_VERIFICATION_NOT_ENROLLED (23):
                An account administrator changed this
                account's authentication settings. To access
                this Google Ads account, enable 2-Step
                Verification in your Google account at
                https://www.google.com/landing/2step.
            ADVANCED_PROTECTION_NOT_ENROLLED (24):
                An account administrator changed this
                account's authentication settings. To access
                this Google Ads account, enable Advanced
                Protection in your Google account at
                https://landing.google.com/advancedprotection.
            ORGANIZATION_NOT_RECOGNIZED (26):
                The Cloud organization associated with the
                project is not recognized.
            ORGANIZATION_NOT_APPROVED (27):
                The Cloud organization associated with the
                project is not approved for prod access.
            ORGANIZATION_NOT_ASSOCIATED_WITH_DEVELOPER_TOKEN (28):
                The Cloud organization associated with the
                project is not associated with the developer
                token.
            DEVELOPER_TOKEN_INVALID (29):
                The developer token is not valid.
        """

        UNSPECIFIED = 0
        UNKNOWN = 1
        AUTHENTICATION_ERROR = 2
        CLIENT_CUSTOMER_ID_INVALID = 5
        CUSTOMER_NOT_FOUND = 8
        GOOGLE_ACCOUNT_DELETED = 9
        GOOGLE_ACCOUNT_COOKIE_INVALID = 10
        GOOGLE_ACCOUNT_AUTHENTICATION_FAILED = 25
        GOOGLE_ACCOUNT_USER_AND_ADS_USER_MISMATCH = 12
        LOGIN_COOKIE_REQUIRED = 13
        NOT_ADS_USER = 14
        OAUTH_TOKEN_INVALID = 15
        OAUTH_TOKEN_EXPIRED = 16
        OAUTH_TOKEN_DISABLED = 17
        OAUTH_TOKEN_REVOKED = 18
        OAUTH_TOKEN_HEADER_INVALID = 19
        LOGIN_COOKIE_INVALID = 20
        USER_ID_INVALID = 22
        TWO_STEP_VERIFICATION_NOT_ENROLLED = 23
        ADVANCED_PROTECTION_NOT_ENROLLED = 24
        ORGANIZATION_NOT_RECOGNIZED = 26
        ORGANIZATION_NOT_APPROVED = 27
        ORGANIZATION_NOT_ASSOCIATED_WITH_DEVELOPER_TOKEN = 28
        DEVELOPER_TOKEN_INVALID = 29


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations


import proto  # type: ignore


__protobuf__ = proto.module(
    package="google.ads.googleads.v19.errors",
    marshal="google.ads.googleads.v19",
    manifest={
        "NewResourceCreationErrorEnum",
    },
)


class NewResourceCreationErrorEnum(proto.Message):
    r"""Container for enum describing possible new resource creation
    errors.

    """

    class NewResourceCreationError(proto.Enum):
        r"""Enum describing possible new resource creation errors.

        Values:
            UNSPECIFIED (0):
                Enum unspecified.
            UNKNOWN (1):
                The received error code is not known in this
                version.
            CANNOT_SET_ID_FOR_CREATE (2):
                Do not set the id field while creating new
                resources.
            DUPLICATE_TEMP_IDS (3):
                Creating more than one resource with the same
                temp ID is not allowed.
            TEMP_ID_RESOURCE_HAD_ERRORS (4):
                Parent resource with specified temp ID failed
                validation, so no validation will be done for
                this child resource.
        """

        UNSPECIFIED = 0
        UNKNOWN = 1
        CANNOT_SET_ID_FOR_CREATE = 2
        DUPLICATE_TEMP_IDS = 3
        TEMP_ID_RESOURCE_HAD_ERRORS = 4


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations


import proto  # type: ignore


__protobuf__ = proto.module(
    package="google.ads.googleads.v20.enums",
    marshal="google.ads.googleads.v20",
    manifest={
        "ConversionValueRuleSetStatusEnum",
    },
)


class ConversionValueRuleSetStatusEnum(proto.Message):
    r"""Container for enum describing possible statuses of a
    conversion value rule set.

    """

    class ConversionValueRuleSetStatus(proto.Enum):
        r"""Possible statuses of a conversion value rule set.

        Values:
            UNSPECIFIED (0):
                Not specified.
            UNKNOWN (1):
                Used for return value only. Represents value
                unknown in this version.
            ENABLED (2):
                Conversion Value Rule Set is enabled and can
                be applied.
            REMOVED (3):
                Conversion Value Rule Set is permanently
                deleted and can't be applied.
            PAUSED (4):
                Conversion Value Rule Set is paused and won't
                be applied. It can be enabled again.
        """

        UNSPECIFIED = 0
        UNKNOWN = 1
        ENABLED = 2
        REMOVED = 3
        PAUSED = 4


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations


import proto  # type: ignore


__protobuf__ = proto.module(
    package="google.ads.googleads.v20.errors",
    marshal="google.ads.googleads.v20",
    manifest={
        "CampaignLifecycleGoalErrorEnum",
    },
)


class CampaignLifecycleGoalErrorEnum(proto.Message):
    r"""Container for enum describing possible campaign lifecycle
    goal errors.

    """

    class CampaignLifecycleGoalError(proto.Enum):
        r"""Enum describing possible campaign lifecycle goal errors.

        Values:
            UNSPECIFIED (0):
                Enum unspecified.
            UNKNOWN (1):
                The received error code is not known in this
                version.
            CAMPAIGN_MISSING (2):
                Campaign is not specified.
            INVALID_CAMPAIGN (3):
                Cannot find the specified campaign.
            CUSTOMER_ACQUISITION_INVALID_OPTIMIZATION_MODE (4):
                Optimization mode is unspecified or invalid.
            INCOMPATIBLE_BIDDING_STRATEGY (5):
                The configured lifecycle goal setting is not compatible with
                the bidding strategy the campaign is using. Specifically,
                BID_HIGHER_FOR_NEW_CUSTOMER requires conversion-value based
                bidding strategy type such as MAXIMIZE_CONVERSION_VALUE.
            MISSING_PURCHASE_GOAL (6):
                Lifecycle goals require the campaign to
                optimize towards purchase conversion goal.
            CUSTOMER_ACQUISITION_INVALID_HIGH_LIFETIME_VALUE (7):
                CampaignLifecycleGoal.customer_acquisition_goal_settings.value_settings.high_lifetime_value
                is invalid or not allowed, such as when the specified value
                is smaller than 0.01, when the optimization mode is not
                BID_HIGHER_FOR_NEW_CUSTOMER, or when
                CampaignLifecycleGoal.customer_acquisition_goal_settings.value_settings.high_lifetime_value
                is specified smaller than/without
                CampaignLifecycleGoal.customer_acquisition_goal_settings.value_settings.value.
            CUSTOMER_ACQUISITION_UNSUPPORTED_CAMPAIGN_TYPE (8):
                Customer acquisition goal is not supported on
                this campaign type.
            CUSTOMER_ACQUISITION_INVALID_VALUE (9):
                CampaignLifecycleGoal.customer_acquisition_goal_settings.value_settings.value
                is invalid or not allowed, such as when the specified value
                is smaller than 0.01, or when the optimization mode is not
                BID_HIGHER_FOR_NEW_CUSTOMER.
            CUSTOMER_ACQUISITION_VALUE_MISSING (10):
                To use BID_HIGHER_FOR_NEW_CUSTOMER mode, either
                CampaignLifecycleGoal.customer_acquisition_goal_settings.value_settings.value
                or
                CustomerLifecycleGoal.customer_acquisition_goal_value_settings.value
                must have been specified. If a manager account is managing
                your account's conversion tracking, then only the
                CustomerLifecycleGoal of that manager account is used.
            CUSTOMER_ACQUISITION_MISSING_EXISTING_CUSTOMER_DEFINITION (11):
                In order for a campaign to adopt the customer acquisition
                goal,
                CustomerLifecycleGoal.lifecycle_goal_customer_definition_settings.existing_user_lists
                must include active and accessible userlist with more than
                1000 members in the Search/Youtube network. If a manager
                account is managing your account's conversion tracking, then
                only the CustomerLifecycleGoal of that manager account is
                used. Also make sure that the manager account shares
                audience segments with sub-accounts with continuous audience
                sharing.
            CUSTOMER_ACQUISITION_MISSING_HIGH_VALUE_CUSTOMER_DEFINITION (12):
                In order for a campaign to adopt the customer acquisition
                goal with high lifetime value optimization,
                CustomerLifecycleGoal.lifecycle_goal_customer_definition_settings.high_lifetime_value_user_lists
                must include active and accessible userlist with more than
                1000 members in the Search/Youtube network. If a manager
                account is managing your account's conversion tracking, then
                only the CustomerLifecycleGoal of that manager account is
                used. Also make sure that the manager account shares
                audience segments with sub-accounts using continuous
                audience sharing.
        """

        UNSPECIFIED = 0
        UNKNOWN = 1
        CAMPAIGN_MISSING = 2
        INVALID_CAMPAIGN = 3
        CUSTOMER_ACQUISITION_INVALID_OPTIMIZATION_MODE = 4
        INCOMPATIBLE_BIDDING_STRATEGY = 5
        MISSING_PURCHASE_GOAL = 6
        CUSTOMER_ACQUISITION_INVALID_HIGH_LIFETIME_VALUE = 7
        CUSTOMER_ACQUISITION_UNSUPPORTED_CAMPAIGN_TYPE = 8
        CUSTOMER_ACQUISITION_INVALID_VALUE = 9
        CUSTOMER_ACQUISITION_VALUE_MISSING = 10
        CUSTOMER_ACQUISITION_MISSING_EXISTING_CUSTOMER_DEFINITION = 11
        CUSTOMER_ACQUISITION_MISSING_HIGH_VALUE_CUSTOMER_DEFINITION = 12


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableSequence

import proto  # type: ignore

from google.ads.googleads.v21.enums.types import gender_type
from google.ads.googleads.v21.enums.types import income_range_type
from google.ads.googleads.v21.enums.types import parental_status_type


__protobuf__ = proto.module(
    package="google.ads.googleads.v21.common",
    marshal="google.ads.googleads.v21",
    manifest={
        "AudienceDimension",
        "AudienceExclusionDimension",
        "ExclusionSegment",
        "AgeDimension",
        "AgeSegment",
        "GenderDimension",
        "HouseholdIncomeDimension",
        "ParentalStatusDimension",
        "AudienceSegmentDimension",
        "AudienceSegment",
        "UserListSegment",
        "UserInterestSegment",
        "LifeEventSegment",
        "DetailedDemographicSegment",
        "CustomAudienceSegment",
    },
)


class AudienceDimension(proto.Message):
    r"""Positive dimension specifying user's audience.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        age (google.ads.googleads.v21.common.types.AgeDimension):
            Dimension specifying users by their age.

            This field is a member of `oneof`_ ``dimension``.
        gender (google.ads.googleads.v21.common.types.GenderDimension):
            Dimension specifying users by their gender.

            This field is a member of `oneof`_ ``dimension``.
        household_income (google.ads.googleads.v21.common.types.HouseholdIncomeDimension):
            Dimension specifying users by their household
            income.

            This field is a member of `oneof`_ ``dimension``.
        parental_status (google.ads.googleads.v21.common.types.ParentalStatusDimension):
            Dimension specifying users by their parental
            status.

            This field is a member of `oneof`_ ``dimension``.
        audience_segments (google.ads.googleads.v21.common.types.AudienceSegmentDimension):
            Dimension specifying users by their
            membership in other audience segments.

            This field is a member of `oneof`_ ``dimension``.
    """

    age: "AgeDimension" = proto.Field(
        proto.MESSAGE,
        number=1,
        oneof="dimension",
        message="AgeDimension",
    )
    gender: "GenderDimension" = proto.Field(
        proto.MESSAGE,
        number=2,
        oneof="dimension",
        message="GenderDimension",
    )
    household_income: "HouseholdIncomeDimension" = proto.Field(
        proto.MESSAGE,
        number=3,
        oneof="dimension",
        message="HouseholdIncomeDimension",
    )
    parental_status: "ParentalStatusDimension" = proto.Field(
        proto.MESSAGE,
        number=4,
        oneof="dimension",
        message="ParentalStatusDimension",
    )
    audience_segments: "AudienceSegmentDimension" = proto.Field(
        proto.MESSAGE,
        number=5,
        oneof="dimension",
        message="AudienceSegmentDimension",
    )


class AudienceExclusionDimension(proto.Message):
    r"""Negative dimension specifying users to exclude from the
    audience.

    Attributes:
        exclusions (MutableSequence[google.ads.googleads.v21.common.types.ExclusionSegment]):
            Audience segment to be excluded.
    """

    exclusions: MutableSequence["ExclusionSegment"] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="ExclusionSegment",
    )


class ExclusionSegment(proto.Message):
    r"""An audience segment to be excluded from an audience.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        user_list (google.ads.googleads.v21.common.types.UserListSegment):
            User list segment to be excluded.

            This field is a member of `oneof`_ ``segment``.
    """

    user_list: "UserListSegment" = proto.Field(
        proto.MESSAGE,
        number=1,
        oneof="segment",
        message="UserListSegment",
    )


class AgeDimension(proto.Message):
    r"""Dimension specifying users by their age.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        age_ranges (MutableSequence[google.ads.googleads.v21.common.types.AgeSegment]):
            Contiguous age range to be included in the
            dimension.
        include_undetermined (bool):
            Include users whose age is not determined.

            This field is a member of `oneof`_ ``_include_undetermined``.
    """

    age_ranges: MutableSequence["AgeSegment"] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="AgeSegment",
    )
    include_undetermined: bool = proto.Field(
        proto.BOOL,
        number=2,
        optional=True,
    )


class AgeSegment(proto.Message):
    r"""Contiguous age range.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        min_age (int):
            Minimum age to include. A minimum age must be
            specified and must be at least 18. Allowed
            values are 18, 25, 35, 45, 55, and 65.

            This field is a member of `oneof`_ ``_min_age``.
        max_age (int):
            Maximum age to include. A maximum age need not be specified.
            If specified, max_age must be greater than min_age, and
            allowed values are 24, 34, 44, 54, and 64.

            This field is a member of `oneof`_ ``_max_age``.
    """

    min_age: int = proto.Field(
        proto.INT32,
        number=1,
        optional=True,
    )
    max_age: int = proto.Field(
        proto.INT32,
        number=2,
        optional=True,
    )


class GenderDimension(proto.Message):
    r"""Dimension specifying users by their gender.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        genders (MutableSequence[google.ads.googleads.v21.enums.types.GenderTypeEnum.GenderType]):
            Included gender demographic segments.
        include_undetermined (bool):
            Include users whose gender is not determined.

            This field is a member of `oneof`_ ``_include_undetermined``.
    """

    genders: MutableSequence[gender_type.GenderTypeEnum.GenderType] = (
        proto.RepeatedField(
            proto.ENUM,
            number=1,
            enum=gender_type.GenderTypeEnum.GenderType,
        )
    )
    include_undetermined: bool = proto.Field(
        proto.BOOL,
        number=2,
        optional=True,
    )


class HouseholdIncomeDimension(proto.Message):
    r"""Dimension specifying users by their household income.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        income_ranges (MutableSequence[google.ads.googleads.v21.enums.types.IncomeRangeTypeEnum.IncomeRangeType]):
            Included household income demographic
            segments.
        include_undetermined (bool):
            Include users whose household income is not
            determined.

            This field is a member of `oneof`_ ``_include_undetermined``.
    """

    income_ranges: MutableSequence[
        income_range_type.IncomeRangeTypeEnum.IncomeRangeType
    ] = proto.RepeatedField(
        proto.ENUM,
        number=1,
        enum=income_range_type.IncomeRangeTypeEnum.IncomeRangeType,
    )
    include_undetermined: bool = proto.Field(
        proto.BOOL,
        number=2,
        optional=True,
    )


class ParentalStatusDimension(proto.Message):
    r"""Dimension specifying users by their parental status.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        parental_statuses (MutableSequence[google.ads.googleads.v21.enums.types.ParentalStatusTypeEnum.ParentalStatusType]):
            Included parental status demographic
            segments.
        include_undetermined (bool):
            Include users whose parental status is
            undetermined.

            This field is a member of `oneof`_ ``_include_undetermined``.
    """

    parental_statuses: MutableSequence[
        parental_status_type.ParentalStatusTypeEnum.ParentalStatusType
    ] = proto.RepeatedField(
        proto.ENUM,
        number=1,
        enum=parental_status_type.ParentalStatusTypeEnum.ParentalStatusType,
    )
    include_undetermined: bool = proto.Field(
        proto.BOOL,
        number=2,
        optional=True,
    )


class AudienceSegmentDimension(proto.Message):
    r"""Dimension specifying users by their membership in other
    audience segments.

    Attributes:
        segments (MutableSequence[google.ads.googleads.v21.common.types.AudienceSegment]):
            Included audience segments. Users are
            included if they belong to at least one segment.
    """

    segments: MutableSequence["AudienceSegment"] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="AudienceSegment",
    )


class AudienceSegment(proto.Message):
    r"""Positive audience segment.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        user_list (google.ads.googleads.v21.common.types.UserListSegment):
            User list segment.

            This field is a member of `oneof`_ ``segment``.
        user_interest (google.ads.googleads.v21.common.types.UserInterestSegment):
            Affinity or In-market segment.

            This field is a member of `oneof`_ ``segment``.
        life_event (google.ads.googleads.v21.common.types.LifeEventSegment):
            Live-event audience segment.

            This field is a member of `oneof`_ ``segment``.
        detailed_demographic (google.ads.googleads.v21.common.types.DetailedDemographicSegment):
            Detailed demographic segment.

            This field is a member of `oneof`_ ``segment``.
        custom_audience (google.ads.googleads.v21.common.types.CustomAudienceSegment):
            Custom audience segment.

            This field is a member of `oneof`_ ``segment``.
    """

    user_list: "UserListSegment" = proto.Field(
        proto.MESSAGE,
        number=1,
        oneof="segment",
        message="UserListSegment",
    )
    user_interest: "UserInterestSegment" = proto.Field(
        proto.MESSAGE,
        number=2,
        oneof="segment",
        message="UserInterestSegment",
    )
    life_event: "LifeEventSegment" = proto.Field(
        proto.MESSAGE,
        number=3,
        oneof="segment",
        message="LifeEventSegment",
    )
    detailed_demographic: "DetailedDemographicSegment" = proto.Field(
        proto.MESSAGE,
        number=4,
        oneof="segment",
        message="DetailedDemographicSegment",
    )
    custom_audience: "CustomAudienceSegment" = proto.Field(
        proto.MESSAGE,
        number=5,
        oneof="segment",
        message="CustomAudienceSegment",
    )


class UserListSegment(proto.Message):
    r"""User list segment.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        user_list (str):
            The user list resource.

            This field is a member of `oneof`_ ``_user_list``.
    """

    user_list: str = proto.Field(
        proto.STRING,
        number=1,
        optional=True,
    )


class UserInterestSegment(proto.Message):
    r"""User interest segment.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        user_interest_category (str):
            The user interest resource.

            This field is a member of `oneof`_ ``_user_interest_category``.
    """

    user_interest_category: str = proto.Field(
        proto.STRING,
        number=1,
        optional=True,
    )


class LifeEventSegment(proto.Message):
    r"""Live event segment.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        life_event (str):
            The life event resource.

            This field is a member of `oneof`_ ``_life_event``.
    """

    life_event: str = proto.Field(
        proto.STRING,
        number=1,
        optional=True,
    )


class DetailedDemographicSegment(proto.Message):
    r"""Detailed demographic segment.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        detailed_demographic (str):
            The detailed demographic resource.

            This field is a member of `oneof`_ ``_detailed_demographic``.
    """

    detailed_demographic: str = proto.Field(
        proto.STRING,
        number=1,
        optional=True,
    )


class CustomAudienceSegment(proto.Message):
    r"""Custom audience segment.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        custom_audience (str):
            The custom audience resource.

            This field is a member of `oneof`_ ``_custom_audience``.
    """

    custom_audience: str = proto.Field(
        proto.STRING,
        number=1,
        optional=True,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableSequence

import proto  # type: ignore

from google.ads.googleads.v22.common.types import custom_parameter
from google.ads.googleads.v22.enums.types import (
    call_conversion_reporting_state as gage_call_conversion_reporting_state,
)


__protobuf__ = proto.module(
    package="google.ads.googleads.v22.common",
    marshal="google.ads.googleads.v22",
    manifest={
        "CallFeedItem",
        "CalloutFeedItem",
        "SitelinkFeedItem",
    },
)


class CallFeedItem(proto.Message):
    r"""Represents a Call extension.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        phone_number (str):
            The advertiser's phone number to append to
            the ad. This string must not be empty.

            This field is a member of `oneof`_ ``_phone_number``.
        country_code (str):
            Uppercase two-letter country code of the
            advertiser's phone number. This string must not
            be empty.

            This field is a member of `oneof`_ ``_country_code``.
        call_tracking_enabled (bool):
            Indicates whether call tracking is enabled.
            By default, call tracking is not enabled.

            This field is a member of `oneof`_ ``_call_tracking_enabled``.
        call_conversion_action (str):
            The conversion action to attribute a call conversion to. If
            not set a default conversion action is used. This field only
            has effect if call_tracking_enabled is set to true.
            Otherwise this field is ignored.

            This field is a member of `oneof`_ ``_call_conversion_action``.
        call_conversion_tracking_disabled (bool):
            If true, disable call conversion tracking.
            call_conversion_action should not be set if this is true.
            Optional.

            This field is a member of `oneof`_ ``_call_conversion_tracking_disabled``.
        call_conversion_reporting_state (google.ads.googleads.v22.enums.types.CallConversionReportingStateEnum.CallConversionReportingState):
            Enum value that indicates whether this call
            extension uses its own call conversion setting
            (or just have call conversion disabled), or
            following the account level setting.
    """

    phone_number: str = proto.Field(
        proto.STRING,
        number=7,
        optional=True,
    )
    country_code: str = proto.Field(
        proto.STRING,
        number=8,
        optional=True,
    )
    call_tracking_enabled: bool = proto.Field(
        proto.BOOL,
        number=9,
        optional=True,
    )
    call_conversion_action: str = proto.Field(
        proto.STRING,
        number=10,
        optional=True,
    )
    call_conversion_tracking_disabled: bool = proto.Field(
        proto.BOOL,
        number=11,
        optional=True,
    )
    call_conversion_reporting_state: (
        gage_call_conversion_reporting_state.CallConversionReportingStateEnum.CallConversionReportingState
    ) = proto.Field(
        proto.ENUM,
        number=6,
        enum=gage_call_conversion_reporting_state.CallConversionReportingStateEnum.CallConversionReportingState,
    )


class CalloutFeedItem(proto.Message):
    r"""Represents a callout extension.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        callout_text (str):
            The callout text.
            The length of this string should be between 1
            and 25, inclusive.

            This field is a member of `oneof`_ ``_callout_text``.
    """

    callout_text: str = proto.Field(
        proto.STRING,
        number=2,
        optional=True,
    )


class SitelinkFeedItem(proto.Message):
    r"""Represents a sitelink.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        link_text (str):
            URL display text for the sitelink.
            The length of this string should be between 1
            and 25, inclusive.

            This field is a member of `oneof`_ ``_link_text``.
        line1 (str):
            First line of the description for the
            sitelink. If this value is set, line2 must also
            be set. The length of this string should be
            between 0 and 35, inclusive.

            This field is a member of `oneof`_ ``_line1``.
        line2 (str):
            Second line of the description for the
            sitelink. If this value is set, line1 must also
            be set. The length of this string should be
            between 0 and 35, inclusive.

            This field is a member of `oneof`_ ``_line2``.
        final_urls (MutableSequence[str]):
            A list of possible final URLs after all cross
            domain redirects.
        final_mobile_urls (MutableSequence[str]):
            A list of possible final mobile URLs after
            all cross domain redirects.
        tracking_url_template (str):
            URL template for constructing a tracking URL.

            This field is a member of `oneof`_ ``_tracking_url_template``.
        url_custom_parameters (MutableSequence[google.ads.googleads.v22.common.types.CustomParameter]):
            A list of mappings to be used for substituting URL custom
            parameter tags in the tracking_url_template, final_urls,
            and/or final_mobile_urls.
        final_url_suffix (str):
            Final URL suffix to be appended to landing
            page URLs served with parallel tracking.

            This field is a member of `oneof`_ ``_final_url_suffix``.
    """

    link_text: str = proto.Field(
        proto.STRING,
        number=9,
        optional=True,
    )
    line1: str = proto.Field(
        proto.STRING,
        number=10,
        optional=True,
    )
    line2: str = proto.Field(
        proto.STRING,
        number=11,
        optional=True,
    )
    final_urls: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=12,
    )
    final_mobile_urls: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=13,
    )
    tracking_url_template: str = proto.Field(
        proto.STRING,
        number=14,
        optional=True,
    )
    url_custom_parameters: MutableSequence[custom_parameter.CustomParameter] = (
        proto.RepeatedField(
            proto.MESSAGE,
            number=7,
            message=custom_parameter.CustomParameter,
        )
    )
    final_url_suffix: str = proto.Field(
        proto.STRING,
        number=15,
        optional=True,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations


import proto  # type: ignore

from google.ads.googleads.v21.enums.types import change_status_operation
from google.ads.googleads.v21.enums.types import change_status_resource_type


__protobuf__ = proto.module(
    package="google.ads.googleads.v21.resources",
    marshal="google.ads.googleads.v21",
    manifest={
        "ChangeStatus",
    },
)


class ChangeStatus(proto.Message):
    r"""Describes the status of returned resource. ChangeStatus could
    have up to 3 minutes delay to reflect a new change.


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        resource_name (str):
            Output only. The resource name of the change status. Change
            status resource names have the form:

            ``customers/{customer_id}/changeStatus/{change_status_id}``
        last_change_date_time (str):
            Output only. Time at which the most recent
            change has occurred on this resource.

            This field is a member of `oneof`_ ``_last_change_date_time``.
        resource_type (google.ads.googleads.v21.enums.types.ChangeStatusResourceTypeEnum.ChangeStatusResourceType):
            Output only. Represents the type of the changed resource.
            This dictates what fields will be set. For example, for
            AD_GROUP, campaign and ad_group fields will be set.
        campaign (str):
            Output only. The Campaign affected by this
            change.

            This field is a member of `oneof`_ ``_campaign``.
        ad_group (str):
            Output only. The AdGroup affected by this
            change.

            This field is a member of `oneof`_ ``_ad_group``.
        resource_status (google.ads.googleads.v21.enums.types.ChangeStatusOperationEnum.ChangeStatusOperation):
            Output only. Represents the status of the
            changed resource.
        ad_group_ad (str):
            Output only. The AdGroupAd affected by this
            change.

            This field is a member of `oneof`_ ``_ad_group_ad``.
        ad_group_criterion (str):
            Output only. The AdGroupCriterion affected by
            this change.

            This field is a member of `oneof`_ ``_ad_group_criterion``.
        campaign_criterion (str):
            Output only. The CampaignCriterion affected
            by this change.

            This field is a member of `oneof`_ ``_campaign_criterion``.
        ad_group_bid_modifier (str):
            Output only. The AdGroupBidModifier affected
            by this change.

            This field is a member of `oneof`_ ``_ad_group_bid_modifier``.
        shared_set (str):
            Output only. The SharedSet affected by this
            change.
        campaign_shared_set (str):
            Output only. The CampaignSharedSet affected
            by this change.
        asset (str):
            Output only. The Asset affected by this
            change.
        customer_asset (str):
            Output only. The CustomerAsset affected by
            this change.
        campaign_asset (str):
            Output only. The CampaignAsset affected by
            this change.
        ad_group_asset (str):
            Output only. The AdGroupAsset affected by
            this change.
        combined_audience (str):
            Output only. The CombinedAudience affected by
            this change.
        asset_group (str):
            Output only. The AssetGroup affected by this
            change.
        asset_set (str):
            Output only. The AssetSet affected by this
            change.
        campaign_budget (str):
            Output only. The CampaignBudget affected by
            this change.
        campaign_asset_set (str):
            Output only. The CampaignAssetSet affected by
            this change.
    """

    resource_name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    last_change_date_time: str = proto.Field(
        proto.STRING,
        number=24,
        optional=True,
    )
    resource_type: (
        change_status_resource_type.ChangeStatusResourceTypeEnum.ChangeStatusResourceType
    ) = proto.Field(
        proto.ENUM,
        number=4,
        enum=change_status_resource_type.ChangeStatusResourceTypeEnum.ChangeStatusResourceType,
    )
    campaign: str = proto.Field(
        proto.STRING,
        number=17,
        optional=True,
    )
    ad_group: str = proto.Field(
        proto.STRING,
        number=18,
        optional=True,
    )
    resource_status: (
        change_status_operation.ChangeStatusOperationEnum.ChangeStatusOperation
    ) = proto.Field(
        proto.ENUM,
        number=8,
        enum=change_status_operation.ChangeStatusOperationEnum.ChangeStatusOperation,
    )
    ad_group_ad: str = proto.Field(
        proto.STRING,
        number=25,
        optional=True,
    )
    ad_group_criterion: str = proto.Field(
        proto.STRING,
        number=26,
        optional=True,
    )
    campaign_criterion: str = proto.Field(
        proto.STRING,
        number=27,
        optional=True,
    )
    ad_group_bid_modifier: str = proto.Field(
        proto.STRING,
        number=32,
        optional=True,
    )
    shared_set: str = proto.Field(
        proto.STRING,
        number=33,
    )
    campaign_shared_set: str = proto.Field(
        proto.STRING,
        number=34,
    )
    asset: str = proto.Field(
        proto.STRING,
        number=35,
    )
    customer_asset: str = proto.Field(
        proto.STRING,
        number=36,
    )
    campaign_asset: str = proto.Field(
        proto.STRING,
        number=37,
    )
    ad_group_asset: str = proto.Field(
        proto.STRING,
        number=38,
    )
    combined_audience: str = proto.Field(
        proto.STRING,
        number=40,
    )
    asset_group: str = proto.Field(
        proto.STRING,
        number=41,
    )
    asset_set: str = proto.Field(
        proto.STRING,
        number=43,
    )
    campaign_budget: str = proto.Field(
        proto.STRING,
        number=42,
    )
    campaign_asset_set: str = proto.Field(
        proto.STRING,
        number=44,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations


import proto  # type: ignore


__protobuf__ = proto.module(
    package="google.ads.googleads.v20.errors",
    marshal="google.ads.googleads.v20",
    manifest={
        "BrandGuidelinesMigrationErrorEnum",
    },
)


class BrandGuidelinesMigrationErrorEnum(proto.Message):
    r"""Container for enum describing brand guidelines migration
    errors.

    """

    class BrandGuidelinesMigrationError(proto.Enum):
        r"""Enum describing brand guidelines migration errors.

        Values:
            UNSPECIFIED (0):
                Enum unspecified.
            UNKNOWN (1):
                The received error code is not known in this
                version.
            BRAND_GUIDELINES_ALREADY_ENABLED (2):
                This campaign is already enabled for Brand
                Guidelines.
            CANNOT_ENABLE_BRAND_GUIDELINES_FOR_REMOVED_CAMPAIGN (3):
                Brand Guidelines can only be enabled for
                active or suspended campaigns.
            BRAND_GUIDELINES_LOGO_LIMIT_EXCEEDED (4):
                Maximum of 5 square and landscape logos can
                be specified for Brand Guidelines.
            CANNOT_AUTO_POPULATE_BRAND_ASSETS_WHEN_BRAND_ASSETS_PROVIDED (5):
                Either auto_populate_brand_assets must be true or
                brand_assets must be provided, but not both.
            AUTO_POPULATE_BRAND_ASSETS_REQUIRED_WHEN_BRAND_ASSETS_OMITTED (6):
                Either auto_populate_brand_assets can be false or
                brand_assets can be omitted, but not both.
            TOO_MANY_ENABLE_OPERATIONS (7):
                A maximum of 10 enable operations can be
                executed in a request.
        """

        UNSPECIFIED = 0
        UNKNOWN = 1
        BRAND_GUIDELINES_ALREADY_ENABLED = 2
        CANNOT_ENABLE_BRAND_GUIDELINES_FOR_REMOVED_CAMPAIGN = 3
        BRAND_GUIDELINES_LOGO_LIMIT_EXCEEDED = 4
        CANNOT_AUTO_POPULATE_BRAND_ASSETS_WHEN_BRAND_ASSETS_PROVIDED = 5
        AUTO_POPULATE_BRAND_ASSETS_REQUIRED_WHEN_BRAND_ASSETS_OMITTED = 6
        TOO_MANY_ENABLE_OPERATIONS = 7


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from google.ads.googleads.v20 import gapic_version as package_version

__version__ = package_version.__version__


from .types.access_invitation_error import AccessInvitationErrorEnum
from .types.account_budget_proposal_error import AccountBudgetProposalErrorEnum
from .types.account_link_error import AccountLinkErrorEnum
from .types.ad_customizer_error import AdCustomizerErrorEnum
from .types.ad_error import AdErrorEnum
from .types.ad_group_ad_error import AdGroupAdErrorEnum
from .types.ad_group_bid_modifier_error import AdGroupBidModifierErrorEnum
from .types.ad_group_criterion_customizer_error import (
    AdGroupCriterionCustomizerErrorEnum,
)
from .types.ad_group_criterion_error import AdGroupCriterionErrorEnum
from .types.ad_group_customizer_error import AdGroupCustomizerErrorEnum
from .types.ad_group_error import AdGroupErrorEnum
from .types.ad_group_feed_error import AdGroupFeedErrorEnum
from .types.ad_parameter_error import AdParameterErrorEnum
from .types.ad_sharing_error import AdSharingErrorEnum
from .types.adx_error import AdxErrorEnum
from .types.asset_error import AssetErrorEnum
from .types.asset_group_asset_error import AssetGroupAssetErrorEnum
from .types.asset_group_error import AssetGroupErrorEnum
from .types.asset_group_listing_group_filter_error import (
    AssetGroupListingGroupFilterErrorEnum,
)
from .types.asset_group_signal_error import AssetGroupSignalErrorEnum
from .types.asset_link_error import AssetLinkErrorEnum
from .types.asset_set_asset_error import AssetSetAssetErrorEnum
from .types.asset_set_error import AssetSetErrorEnum
from .types.asset_set_link_error import AssetSetLinkErrorEnum
from .types.audience_error import AudienceErrorEnum
from .types.audience_insights_error import AudienceInsightsErrorEnum
from .types.authentication_error import AuthenticationErrorEnum
from .types.authorization_error import AuthorizationErrorEnum
from .types.automatically_created_asset_removal_error import (
    AutomaticallyCreatedAssetRemovalErrorEnum,
)
from .types.batch_job_error import BatchJobErrorEnum
from .types.bidding_error import BiddingErrorEnum
from .types.bidding_strategy_error import BiddingStrategyErrorEnum
from .types.billing_setup_error import BillingSetupErrorEnum
from .types.brand_guidelines_migration_error import (
    BrandGuidelinesMigrationErrorEnum,
)
from .types.campaign_budget_error import CampaignBudgetErrorEnum
from .types.campaign_conversion_goal_error import (
    CampaignConversionGoalErrorEnum,
)
from .types.campaign_criterion_error import CampaignCriterionErrorEnum
from .types.campaign_customizer_error import CampaignCustomizerErrorEnum
from .types.campaign_draft_error import CampaignDraftErrorEnum
from .types.campaign_error import CampaignErrorEnum
from .types.campaign_experiment_error import CampaignExperimentErrorEnum
from .types.campaign_feed_error import CampaignFeedErrorEnum
from .types.campaign_lifecycle_goal_error import CampaignLifecycleGoalErrorEnum
from .types.campaign_shared_set_error import CampaignSharedSetErrorEnum
from .types.change_event_error import ChangeEventErrorEnum
from .types.change_status_error import ChangeStatusErrorEnum
from .types.click_view_error import ClickViewErrorEnum
from .types.collection_size_error import CollectionSizeErrorEnum
from .types.context_error import ContextErrorEnum
from .types.conversion_action_error import ConversionActionErrorEnum
from .types.conversion_adjustment_upload_error import (
    ConversionAdjustmentUploadErrorEnum,
)
from .types.conversion_custom_variable_error import (
    ConversionCustomVariableErrorEnum,
)
from .types.conversion_goal_campaign_config_error import (
    ConversionGoalCampaignConfigErrorEnum,
)
from .types.conversion_upload_error import ConversionUploadErrorEnum
from .types.conversion_value_rule_error import ConversionValueRuleErrorEnum
from .types.conversion_value_rule_set_error import (
    ConversionValueRuleSetErrorEnum,
)
from .types.country_code_error import CountryCodeErrorEnum
from .types.criterion_error import CriterionErrorEnum
from .types.currency_code_error import CurrencyCodeErrorEnum
from .types.currency_error import CurrencyErrorEnum
from .types.custom_audience_error import CustomAudienceErrorEnum
from .types.custom_conversion_goal_error import CustomConversionGoalErrorEnum
from .types.custom_interest_error import CustomInterestErrorEnum
from .types.customer_client_link_error import CustomerClientLinkErrorEnum
from .types.customer_customizer_error import CustomerCustomizerErrorEnum
from .types.customer_error import CustomerErrorEnum
from .types.customer_feed_error import CustomerFeedErrorEnum
from .types.customer_lifecycle_goal_error import CustomerLifecycleGoalErrorEnum
from .types.customer_manager_link_error import CustomerManagerLinkErrorEnum
from .types.customer_sk_ad_network_conversion_value_schema_error import (
    CustomerSkAdNetworkConversionValueSchemaErrorEnum,
)
from .types.customer_user_access_error import CustomerUserAccessErrorEnum
from .types.customizer_attribute_error import CustomizerAttributeErrorEnum
from .types.data_link_error import DataLinkErrorEnum
from .types.database_error import DatabaseErrorEnum
from .types.date_error import DateErrorEnum
from .types.date_range_error import DateRangeErrorEnum
from .types.distinct_error import DistinctErrorEnum
from .types.enum_error import EnumErrorEnum
from .types.errors import ErrorCode
from .types.errors import ErrorDetails
from .types.errors import ErrorLocation
from .types.errors import GoogleAdsError
from .types.errors import GoogleAdsFailure
from .types.errors import PolicyFindingDetails
from .types.errors import PolicyViolationDetails
from .types.errors import QuotaErrorDetails
from .types.errors import ResourceCountDetails
from .types.experiment_arm_error import ExperimentArmErrorEnum
from .types.experiment_error import ExperimentErrorEnum
from .types.extension_feed_item_error import ExtensionFeedItemErrorEnum
from .types.extension_setting_error import ExtensionSettingErrorEnum
from .types.feed_attribute_reference_error import (
    FeedAttributeReferenceErrorEnum,
)
from .types.feed_error import FeedErrorEnum
from .types.feed_item_error import FeedItemErrorEnum
from .types.feed_item_set_error import FeedItemSetErrorEnum
from .types.feed_item_set_link_error import FeedItemSetLinkErrorEnum
from .types.feed_item_target_error import FeedItemTargetErrorEnum
from .types.feed_item_validation_error import FeedItemValidationErrorEnum
from .types.feed_mapping_error import FeedMappingErrorEnum
from .types.field_error import FieldErrorEnum
from .types.field_mask_error import FieldMaskErrorEnum
from .types.function_error import FunctionErrorEnum
from .types.function_parsing_error import FunctionParsingErrorEnum
from .types.geo_target_constant_suggestion_error import (
    GeoTargetConstantSuggestionErrorEnum,
)
from .types.header_error import HeaderErrorEnum
from .types.id_error import IdErrorEnum
from .types.identity_verification_error import IdentityVerificationErrorEnum
from .types.image_error import ImageErrorEnum
from .types.internal_error import InternalErrorEnum
from .types.invoice_error import InvoiceErrorEnum
from .types.keyword_plan_ad_group_error import KeywordPlanAdGroupErrorEnum
from .types.keyword_plan_ad_group_keyword_error import (
    KeywordPlanAdGroupKeywordErrorEnum,
)
from .types.keyword_plan_campaign_error import KeywordPlanCampaignErrorEnum
from .types.keyword_plan_campaign_keyword_error import (
    KeywordPlanCampaignKeywordErrorEnum,
)
from .types.keyword_plan_error import KeywordPlanErrorEnum
from .types.keyword_plan_idea_error import KeywordPlanIdeaErrorEnum
from .types.label_error import LabelErrorEnum
from .types.language_code_error import LanguageCodeErrorEnum
from .types.list_operation_error import ListOperationErrorEnum
from .types.manager_link_error import ManagerLinkErrorEnum
from .types.media_bundle_error import MediaBundleErrorEnum
from .types.media_file_error import MediaFileErrorEnum
from .types.media_upload_error import MediaUploadErrorEnum
from .types.merchant_center_error import MerchantCenterErrorEnum
from .types.multiplier_error import MultiplierErrorEnum
from .types.mutate_error import MutateErrorEnum
from .types.new_resource_creation_error import NewResourceCreationErrorEnum
from .types.not_allowlisted_error import NotAllowlistedErrorEnum
from .types.not_empty_error import NotEmptyErrorEnum
from .types.null_error import NullErrorEnum
from .types.offline_user_data_job_error import OfflineUserDataJobErrorEnum
from .types.operation_access_denied_error import OperationAccessDeniedErrorEnum
from .types.operator_error import OperatorErrorEnum
from .types.partial_failure_error import PartialFailureErrorEnum
from .types.payments_account_error import PaymentsAccountErrorEnum
from .types.policy_finding_error import PolicyFindingErrorEnum
from .types.policy_validation_parameter_error import (
    PolicyValidationParameterErrorEnum,
)
from .types.policy_violation_error import PolicyViolationErrorEnum
from .types.product_link_error import ProductLinkErrorEnum
from .types.product_link_invitation_error import ProductLinkInvitationErrorEnum
from .types.query_error import QueryErrorEnum
from .types.quota_error import QuotaErrorEnum
from .types.range_error import RangeErrorEnum
from .types.reach_plan_error import ReachPlanErrorEnum
from .types.recommendation_error import RecommendationErrorEnum
from .types.recommendation_subscription_error import (
    RecommendationSubscriptionErrorEnum,
)
from .types.region_code_error import RegionCodeErrorEnum
from .types.request_error import RequestErrorEnum
from .types.resource_access_denied_error import ResourceAccessDeniedErrorEnum
from .types.resource_count_limit_exceeded_error import (
    ResourceCountLimitExceededErrorEnum,
)
from .types.search_term_insight_error import SearchTermInsightErrorEnum
from .types.setting_error import SettingErrorEnum
from .types.shareable_preview_error import ShareablePreviewErrorEnum
from .types.shared_criterion_error import SharedCriterionErrorEnum
from .types.shared_set_error import SharedSetErrorEnum
from .types.shopping_product_error import ShoppingProductErrorEnum
from .types.size_limit_error import SizeLimitErrorEnum
from .types.smart_campaign_error import SmartCampaignErrorEnum
from .types.string_format_error import StringFormatErrorEnum
from .types.string_length_error import StringLengthErrorEnum
from .types.third_party_app_analytics_link_error import (
    ThirdPartyAppAnalyticsLinkErrorEnum,
)
from .types.time_zone_error import TimeZoneErrorEnum
from .types.url_field_error import UrlFieldErrorEnum
from .types.user_data_error import UserDataErrorEnum
from .types.user_list_customer_type_error import UserListCustomerTypeErrorEnum
from .types.user_list_error import UserListErrorEnum
from .types.video_campaign_error import VideoCampaignErrorEnum
from .types.youtube_video_registration_error import (
    YoutubeVideoRegistrationErrorEnum,
)

__all__ = (
    "AccessInvitationErrorEnum",
    "AccountBudgetProposalErrorEnum",
    "AccountLinkErrorEnum",
    "AdCustomizerErrorEnum",
    "AdErrorEnum",
    "AdGroupAdErrorEnum",
    "AdGroupBidModifierErrorEnum",
    "AdGroupCriterionCustomizerErrorEnum",
    "AdGroupCriterionErrorEnum",
    "AdGroupCustomizerErrorEnum",
    "AdGroupErrorEnum",
    "AdGroupFeedErrorEnum",
    "AdParameterErrorEnum",
    "AdSharingErrorEnum",
    "AdxErrorEnum",
    "AssetErrorEnum",
    "AssetGroupAssetErrorEnum",
    "AssetGroupErrorEnum",
    "AssetGroupListingGroupFilterErrorEnum",
    "AssetGroupSignalErrorEnum",
    "AssetLinkErrorEnum",
    "AssetSetAssetErrorEnum",
    "AssetSetErrorEnum",
    "AssetSetLinkErrorEnum",
    "AudienceErrorEnum",
    "AudienceInsightsErrorEnum",
    "AuthenticationErrorEnum",
    "AuthorizationErrorEnum",
    "AutomaticallyCreatedAssetRemovalErrorEnum",
    "BatchJobErrorEnum",
    "BiddingErrorEnum",
    "BiddingStrategyErrorEnum",
    "BillingSetupErrorEnum",
    "BrandGuidelinesMigrationErrorEnum",
    "CampaignBudgetErrorEnum",
    "CampaignConversionGoalErrorEnum",
    "CampaignCriterionErrorEnum",
    "CampaignCustomizerErrorEnum",
    "CampaignDraftErrorEnum",
    "CampaignErrorEnum",
    "CampaignExperimentErrorEnum",
    "CampaignFeedErrorEnum",
    "CampaignLifecycleGoalErrorEnum",
    "CampaignSharedSetErrorEnum",
    "ChangeEventErrorEnum",
    "ChangeStatusErrorEnum",
    "ClickViewErrorEnum",
    "CollectionSizeErrorEnum",
    "ContextErrorEnum",
    "ConversionActionErrorEnum",
    "ConversionAdjustmentUploadErrorEnum",
    "ConversionCustomVariableErrorEnum",
    "ConversionGoalCampaignConfigErrorEnum",
    "ConversionUploadErrorEnum",
    "ConversionValueRuleErrorEnum",
    "ConversionValueRuleSetErrorEnum",
    "CountryCodeErrorEnum",
    "CriterionErrorEnum",
    "CurrencyCodeErrorEnum",
    "CurrencyErrorEnum",
    "CustomAudienceErrorEnum",
    "CustomConversionGoalErrorEnum",
    "CustomInterestErrorEnum",
    "CustomerClientLinkErrorEnum",
    "CustomerCustomizerErrorEnum",
    "CustomerErrorEnum",
    "CustomerFeedErrorEnum",
    "CustomerLifecycleGoalErrorEnum",
    "CustomerManagerLinkErrorEnum",
    "CustomerSkAdNetworkConversionValueSchemaErrorEnum",
    "CustomerUserAccessErrorEnum",
    "CustomizerAttributeErrorEnum",
    "DataLinkErrorEnum",
    "DatabaseErrorEnum",
    "DateErrorEnum",
    "DateRangeErrorEnum",
    "DistinctErrorEnum",
    "EnumErrorEnum",
    "ErrorCode",
    "ErrorDetails",
    "ErrorLocation",
    "ExperimentArmErrorEnum",
    "ExperimentErrorEnum",
    "ExtensionFeedItemErrorEnum",
    "ExtensionSettingErrorEnum",
    "FeedAttributeReferenceErrorEnum",
    "FeedErrorEnum",
    "FeedItemErrorEnum",
    "FeedItemSetErrorEnum",
    "FeedItemSetLinkErrorEnum",
    "FeedItemTargetErrorEnum",
    "FeedItemValidationErrorEnum",
    "FeedMappingErrorEnum",
    "FieldErrorEnum",
    "FieldMaskErrorEnum",
    "FunctionErrorEnum",
    "FunctionParsingErrorEnum",
    "GeoTargetConstantSuggestionErrorEnum",
    "GoogleAdsError",
    "GoogleAdsFailure",
    "HeaderErrorEnum",
    "IdErrorEnum",
    "IdentityVerificationErrorEnum",
    "ImageErrorEnum",
    "InternalErrorEnum",
    "InvoiceErrorEnum",
    "KeywordPlanAdGroupErrorEnum",
    "KeywordPlanAdGroupKeywordErrorEnum",
    "KeywordPlanCampaignErrorEnum",
    "KeywordPlanCampaignKeywordErrorEnum",
    "KeywordPlanErrorEnum",
    "KeywordPlanIdeaErrorEnum",
    "LabelErrorEnum",
    "LanguageCodeErrorEnum",
    "ListOperationErrorEnum",
    "ManagerLinkErrorEnum",
    "MediaBundleErrorEnum",
    "MediaFileErrorEnum",
    "MediaUploadErrorEnum",
    "MerchantCenterErrorEnum",
    "MultiplierErrorEnum",
    "MutateErrorEnum",
    "NewResourceCreationErrorEnum",
    "NotAllowlistedErrorEnum",
    "NotEmptyErrorEnum",
    "NullErrorEnum",
    "OfflineUserDataJobErrorEnum",
    "OperationAccessDeniedErrorEnum",
    "OperatorErrorEnum",
    "PartialFailureErrorEnum",
    "PaymentsAccountErrorEnum",
    "PolicyFindingDetails",
    "PolicyFindingErrorEnum",
    "PolicyValidationParameterErrorEnum",
    "PolicyViolationDetails",
    "PolicyViolationErrorEnum",
    "ProductLinkErrorEnum",
    "ProductLinkInvitationErrorEnum",
    "QueryErrorEnum",
    "QuotaErrorDetails",
    "QuotaErrorEnum",
    "RangeErrorEnum",
    "ReachPlanErrorEnum",
    "RecommendationErrorEnum",
    "RecommendationSubscriptionErrorEnum",
    "RegionCodeErrorEnum",
    "RequestErrorEnum",
    "ResourceAccessDeniedErrorEnum",
    "ResourceCountDetails",
    "ResourceCountLimitExceededErrorEnum",
    "SearchTermInsightErrorEnum",
    "SettingErrorEnum",
    "ShareablePreviewErrorEnum",
    "SharedCriterionErrorEnum",
    "SharedSetErrorEnum",
    "ShoppingProductErrorEnum",
    "SizeLimitErrorEnum",
    "SmartCampaignErrorEnum",
    "StringFormatErrorEnum",
    "StringLengthErrorEnum",
    "ThirdPartyAppAnalyticsLinkErrorEnum",
    "TimeZoneErrorEnum",
    "UrlFieldErrorEnum",
    "UserDataErrorEnum",
    "UserListCustomerTypeErrorEnum",
    "UserListErrorEnum",
    "VideoCampaignErrorEnum",
    "YoutubeVideoRegistrationErrorEnum",
)



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableSequence

import proto  # type: ignore

from google.ads.googleads.v19.resources.types import campaign_conversion_goal
from google.protobuf import field_mask_pb2  # type: ignore


__protobuf__ = proto.module(
    package="google.ads.googleads.v19.services",
    marshal="google.ads.googleads.v19",
    manifest={
        "MutateCampaignConversionGoalsRequest",
        "CampaignConversionGoalOperation",
        "MutateCampaignConversionGoalsResponse",
        "MutateCampaignConversionGoalResult",
    },
)


class MutateCampaignConversionGoalsRequest(proto.Message):
    r"""Request message for
    [CampaignConversionGoalService.MutateCampaignConversionGoals][google.ads.googleads.v19.services.CampaignConversionGoalService.MutateCampaignConversionGoals].

    Attributes:
        customer_id (str):
            Required. The ID of the customer whose
            campaign conversion goals are being modified.
        operations (MutableSequence[google.ads.googleads.v19.services.types.CampaignConversionGoalOperation]):
            Required. The list of operations to perform
            on individual campaign conversion goal.
        validate_only (bool):
            If true, the request is validated but not
            executed. Only errors are returned, not results.
    """

    customer_id: str = proto.Field(
        proto.STRING,
        number=1,
    )
    operations: MutableSequence["CampaignConversionGoalOperation"] = (
        proto.RepeatedField(
            proto.MESSAGE,
            number=2,
            message="CampaignConversionGoalOperation",
        )
    )
    validate_only: bool = proto.Field(
        proto.BOOL,
        number=3,
    )


class CampaignConversionGoalOperation(proto.Message):
    r"""A single operation (update) on a campaign conversion goal.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            FieldMask that determines which resource
            fields are modified in an update.
        update (google.ads.googleads.v19.resources.types.CampaignConversionGoal):
            Update operation: The customer conversion
            goal is expected to have a valid resource name.

            This field is a member of `oneof`_ ``operation``.
    """

    update_mask: field_mask_pb2.FieldMask = proto.Field(
        proto.MESSAGE,
        number=2,
        message=field_mask_pb2.FieldMask,
    )
    update: campaign_conversion_goal.CampaignConversionGoal = proto.Field(
        proto.MESSAGE,
        number=1,
        oneof="operation",
        message=campaign_conversion_goal.CampaignConversionGoal,
    )


class MutateCampaignConversionGoalsResponse(proto.Message):
    r"""Response message for a campaign conversion goal mutate.

    Attributes:
        results (MutableSequence[google.ads.googleads.v19.services.types.MutateCampaignConversionGoalResult]):
            All results for the mutate.
    """

    results: MutableSequence["MutateCampaignConversionGoalResult"] = (
        proto.RepeatedField(
            proto.MESSAGE,
            number=1,
            message="MutateCampaignConversionGoalResult",
        )
    )


class MutateCampaignConversionGoalResult(proto.Message):
    r"""The result for the campaign conversion goal mutate.

    Attributes:
        resource_name (str):
            Returned for successful operations.
    """

    resource_name: str = proto.Field(
        proto.STRING,
        number=1,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations


import proto  # type: ignore

from google.ads.googleads.v21.common.types import user_lists
from google.ads.googleads.v21.enums.types import (
    access_reason as gage_access_reason,
)
from google.ads.googleads.v21.enums.types import user_list_access_status
from google.ads.googleads.v21.enums.types import user_list_closing_reason
from google.ads.googleads.v21.enums.types import user_list_membership_status
from google.ads.googleads.v21.enums.types import user_list_size_range
from google.ads.googleads.v21.enums.types import user_list_type


__protobuf__ = proto.module(
    package="google.ads.googleads.v21.resources",
    marshal="google.ads.googleads.v21",
    manifest={
        "UserList",
    },
)


class UserList(proto.Message):
    r"""A user list. This is a list of users a customer may target.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        resource_name (str):
            Immutable. The resource name of the user list. User list
            resource names have the form:

            ``customers/{customer_id}/userLists/{user_list_id}``
        id (int):
            Output only. Id of the user list.

            This field is a member of `oneof`_ ``_id``.
        read_only (bool):
            Output only. An option that indicates if a
            user may edit a list. Depends on the list
            ownership and list type. For example, external
            remarketing user lists are not editable.

            This field is read-only.

            This field is a member of `oneof`_ ``_read_only``.
        name (str):
            Name of this user list. Depending on its access_reason, the
            user list name may not be unique (for example, if
            access_reason=SHARED)

            This field is a member of `oneof`_ ``_name``.
        description (str):
            Description of this user list.

            This field is a member of `oneof`_ ``_description``.
        membership_status (google.ads.googleads.v21.enums.types.UserListMembershipStatusEnum.UserListMembershipStatus):
            Membership status of this user list.
            Indicates whether a user list is open or active.
            Only open user lists can accumulate more users
            and can be targeted to.
        integration_code (str):
            An ID from external system. It is used by
            user list sellers to correlate IDs on their
            systems.

            This field is a member of `oneof`_ ``_integration_code``.
        membership_life_span (int):
            Number of days a user's cookie stays on your list since its
            most recent addition to the list. This field must be between
            0 and 540 inclusive. However, for CRM based userlists, this
            field can be set to 10000 which means no expiration.
            Beginning on April 7, 2025, using a value of 10000 to
            indicate no expiration will no longer be supported.

            This field is ignored for logical_user_list and
            rule_based_user_list types. Membership to lists of these
            types depends on the rules defined by the lists.

            This field is a member of `oneof`_ ``_membership_life_span``.
        size_for_display (int):
            Output only. Estimated number of users in
            this user list, on the Google Display Network.
            This value is null if the number of users has
            not yet been determined.

            This field is read-only.

            This field is a member of `oneof`_ ``_size_for_display``.
        size_range_for_display (google.ads.googleads.v21.enums.types.UserListSizeRangeEnum.UserListSizeRange):
            Output only. Size range in terms of number of
            users of the UserList, on the Google Display
            Network.

            This field is read-only.
        size_for_search (int):
            Output only. Estimated number of users in
            this user list in the google.com domain. These
            are the users available for targeting in Search
            campaigns. This value is null if the number of
            users has not yet been determined.

            This field is read-only.

            This field is a member of `oneof`_ ``_size_for_search``.
        size_range_for_search (google.ads.googleads.v21.enums.types.UserListSizeRangeEnum.UserListSizeRange):
            Output only. Size range in terms of number of
            users of the UserList, for Search ads.

            This field is read-only.
        type_ (google.ads.googleads.v21.enums.types.UserListTypeEnum.UserListType):
            Output only. Type of this list.

            This field is read-only.
        closing_reason (google.ads.googleads.v21.enums.types.UserListClosingReasonEnum.UserListClosingReason):
            Indicating the reason why this user list
            membership status is closed. It is only
            populated on lists that were automatically
            closed due to inactivity, and will be cleared
            once the list membership status becomes open.
        access_reason (google.ads.googleads.v21.enums.types.AccessReasonEnum.AccessReason):
            Output only. Indicates the reason this
            account has been granted access to the list. The
            reason can be SHARED, OWNED, LICENSED or
            SUBSCRIBED.

            This field is read-only.
        account_user_list_status (google.ads.googleads.v21.enums.types.UserListAccessStatusEnum.UserListAccessStatus):
            Indicates if this share is still enabled.
            When a UserList is shared with the user this
            field is set to ENABLED. Later the userList
            owner can decide to revoke the share and make it
            DISABLED.
            The default value of this field is set to
            ENABLED.
        eligible_for_search (bool):
            Indicates if this user list is eligible for
            Google Search Network.

            This field is a member of `oneof`_ ``_eligible_for_search``.
        eligible_for_display (bool):
            Output only. Indicates this user list is
            eligible for Google Display Network.

            This field is read-only.

            This field is a member of `oneof`_ ``_eligible_for_display``.
        match_rate_percentage (int):
            Output only. Indicates match rate for Customer Match lists.
            The range of this field is [0-100]. This will be null for
            other list types or when it's not possible to calculate the
            match rate.

            This field is read-only.

            This field is a member of `oneof`_ ``_match_rate_percentage``.
        crm_based_user_list (google.ads.googleads.v21.common.types.CrmBasedUserListInfo):
            User list of CRM users provided by the
            advertiser.

            This field is a member of `oneof`_ ``user_list``.
        similar_user_list (google.ads.googleads.v21.common.types.SimilarUserListInfo):
            Output only. User list which are similar to
            users from another UserList. These lists are
            readonly and automatically created by google.

            This field is a member of `oneof`_ ``user_list``.
        rule_based_user_list (google.ads.googleads.v21.common.types.RuleBasedUserListInfo):
            User list generated by a rule.

            This field is a member of `oneof`_ ``user_list``.
        logical_user_list (google.ads.googleads.v21.common.types.LogicalUserListInfo):
            User list that is a custom combination of
            user lists and user interests.

            This field is a member of `oneof`_ ``user_list``.
        basic_user_list (google.ads.googleads.v21.common.types.BasicUserListInfo):
            User list targeting as a collection of
            conversion or remarketing actions.

            This field is a member of `oneof`_ ``user_list``.
        lookalike_user_list (google.ads.googleads.v21.common.types.LookalikeUserListInfo):
            Immutable. Lookalike User List.

            This field is a member of `oneof`_ ``user_list``.
    """

    resource_name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    id: int = proto.Field(
        proto.INT64,
        number=25,
        optional=True,
    )
    read_only: bool = proto.Field(
        proto.BOOL,
        number=26,
        optional=True,
    )
    name: str = proto.Field(
        proto.STRING,
        number=27,
        optional=True,
    )
    description: str = proto.Field(
        proto.STRING,
        number=28,
        optional=True,
    )
    membership_status: (
        user_list_membership_status.UserListMembershipStatusEnum.UserListMembershipStatus
    ) = proto.Field(
        proto.ENUM,
        number=6,
        enum=user_list_membership_status.UserListMembershipStatusEnum.UserListMembershipStatus,
    )
    integration_code: str = proto.Field(
        proto.STRING,
        number=29,
        optional=True,
    )
    membership_life_span: int = proto.Field(
        proto.INT64,
        number=30,
        optional=True,
    )
    size_for_display: int = proto.Field(
        proto.INT64,
        number=31,
        optional=True,
    )
    size_range_for_display: (
        user_list_size_range.UserListSizeRangeEnum.UserListSizeRange
    ) = proto.Field(
        proto.ENUM,
        number=10,
        enum=user_list_size_range.UserListSizeRangeEnum.UserListSizeRange,
    )
    size_for_search: int = proto.Field(
        proto.INT64,
        number=32,
        optional=True,
    )
    size_range_for_search: (
        user_list_size_range.UserListSizeRangeEnum.UserListSizeRange
    ) = proto.Field(
        proto.ENUM,
        number=12,
        enum=user_list_size_range.UserListSizeRangeEnum.UserListSizeRange,
    )
    type_: user_list_type.UserListTypeEnum.UserListType = proto.Field(
        proto.ENUM,
        number=13,
        enum=user_list_type.UserListTypeEnum.UserListType,
    )
    closing_reason: (
        user_list_closing_reason.UserListClosingReasonEnum.UserListClosingReason
    ) = proto.Field(
        proto.ENUM,
        number=14,
        enum=user_list_closing_reason.UserListClosingReasonEnum.UserListClosingReason,
    )
    access_reason: gage_access_reason.AccessReasonEnum.AccessReason = (
        proto.Field(
            proto.ENUM,
            number=15,
            enum=gage_access_reason.AccessReasonEnum.AccessReason,
        )
    )
    account_user_list_status: (
        user_list_access_status.UserListAccessStatusEnum.UserListAccessStatus
    ) = proto.Field(
        proto.ENUM,
        number=16,
        enum=user_list_access_status.UserListAccessStatusEnum.UserListAccessStatus,
    )
    eligible_for_search: bool = proto.Field(
        proto.BOOL,
        number=33,
        optional=True,
    )
    eligible_for_display: bool = proto.Field(
        proto.BOOL,
        number=34,
        optional=True,
    )
    match_rate_percentage: int = proto.Field(
        proto.INT32,
        number=24,
        optional=True,
    )
    crm_based_user_list: user_lists.CrmBasedUserListInfo = proto.Field(
        proto.MESSAGE,
        number=19,
        oneof="user_list",
        message=user_lists.CrmBasedUserListInfo,
    )
    similar_user_list: user_lists.SimilarUserListInfo = proto.Field(
        proto.MESSAGE,
        number=20,
        oneof="user_list",
        message=user_lists.SimilarUserListInfo,
    )
    rule_based_user_list: user_lists.RuleBasedUserListInfo = proto.Field(
        proto.MESSAGE,
        number=21,
        oneof="user_list",
        message=user_lists.RuleBasedUserListInfo,
    )
    logical_user_list: user_lists.LogicalUserListInfo = proto.Field(
        proto.MESSAGE,
        number=22,
        oneof="user_list",
        message=user_lists.LogicalUserListInfo,
    )
    basic_user_list: user_lists.BasicUserListInfo = proto.Field(
        proto.MESSAGE,
        number=23,
        oneof="user_list",
        message=user_lists.BasicUserListInfo,
    )
    lookalike_user_list: user_lists.LookalikeUserListInfo = proto.Field(
        proto.MESSAGE,
        number=36,
        oneof="user_list",
        message=user_lists.LookalikeUserListInfo,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations


import proto  # type: ignore


__protobuf__ = proto.module(
    package="google.ads.googleads.v22.enums",
    marshal="google.ads.googleads.v22",
    manifest={
        "UserInterestTaxonomyTypeEnum",
    },
)


class UserInterestTaxonomyTypeEnum(proto.Message):
    r"""Message describing a UserInterestTaxonomyType."""

    class UserInterestTaxonomyType(proto.Enum):
        r"""Enum containing the possible UserInterestTaxonomyTypes.

        Values:
            UNSPECIFIED (0):
                Not specified.
            UNKNOWN (1):
                Used for return value only. Represents value
                unknown in this version.
            AFFINITY (2):
                The affinity for this user interest.
            IN_MARKET (3):
                The market for this user interest.
            MOBILE_APP_INSTALL_USER (4):
                Users known to have installed applications in
                the specified categories.
            VERTICAL_GEO (5):
                The geographical location of the
                interest-based vertical.
            NEW_SMART_PHONE_USER (6):
                User interest criteria for new smart phone
                users.
        """

        UNSPECIFIED = 0
        UNKNOWN = 1
        AFFINITY = 2
        IN_MARKET = 3
        MOBILE_APP_INSTALL_USER = 4
        VERTICAL_GEO = 5
        NEW_SMART_PHONE_USER = 6


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations


import proto  # type: ignore

from google.ads.googleads.v22.common.types import click_location
from google.ads.googleads.v22.common.types import criteria


__protobuf__ = proto.module(
    package="google.ads.googleads.v22.resources",
    marshal="google.ads.googleads.v22",
    manifest={
        "ClickView",
    },
)


class ClickView(proto.Message):
    r"""A click view with metrics aggregated at each click level,
    including both valid and invalid clicks. For non-Search
    campaigns, metrics.clicks represents the number of valid and
    invalid interactions. Queries including ClickView must have a
    filter limiting the results to one day and can be requested for
    dates back to 90 days before the time of the request.


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        resource_name (str):
            Output only. The resource name of the click view. Click view
            resource names have the form:

            ``customers/{customer_id}/clickViews/{date (yyyy-MM-dd)}~{gclid}``
        gclid (str):
            Output only. The Google Click ID.

            This field is a member of `oneof`_ ``_gclid``.
        area_of_interest (google.ads.googleads.v22.common.types.ClickLocation):
            Output only. The location criteria matching
            the area of interest associated with the
            impression.
        location_of_presence (google.ads.googleads.v22.common.types.ClickLocation):
            Output only. The location criteria matching
            the location of presence associated with the
            impression.
        page_number (int):
            Output only. Page number in search results
            where the ad was shown.

            This field is a member of `oneof`_ ``_page_number``.
        ad_group_ad (str):
            Output only. The associated ad.

            This field is a member of `oneof`_ ``_ad_group_ad``.
        campaign_location_target (str):
            Output only. The associated campaign location
            target, if one exists.

            This field is a member of `oneof`_ ``_campaign_location_target``.
        user_list (str):
            Output only. The associated user list, if one
            exists.

            This field is a member of `oneof`_ ``_user_list``.
        keyword (str):
            Output only. The associated keyword, if one
            exists and the click corresponds to the SEARCH
            channel.
        keyword_info (google.ads.googleads.v22.common.types.KeywordInfo):
            Output only. Basic information about the
            associated keyword, if it exists.
    """

    resource_name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    gclid: str = proto.Field(
        proto.STRING,
        number=8,
        optional=True,
    )
    area_of_interest: click_location.ClickLocation = proto.Field(
        proto.MESSAGE,
        number=3,
        message=click_location.ClickLocation,
    )
    location_of_presence: click_location.ClickLocation = proto.Field(
        proto.MESSAGE,
        number=4,
        message=click_location.ClickLocation,
    )
    page_number: int = proto.Field(
        proto.INT64,
        number=9,
        optional=True,
    )
    ad_group_ad: str = proto.Field(
        proto.STRING,
        number=10,
        optional=True,
    )
    campaign_location_target: str = proto.Field(
        proto.STRING,
        number=11,
        optional=True,
    )
    user_list: str = proto.Field(
        proto.STRING,
        number=12,
        optional=True,
    )
    keyword: str = proto.Field(
        proto.STRING,
        number=13,
    )
    keyword_info: criteria.KeywordInfo = proto.Field(
        proto.MESSAGE,
        number=14,
        message=criteria.KeywordInfo,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations


import proto  # type: ignore


__protobuf__ = proto.module(
    package="google.ads.googleads.v19.enums",
    marshal="google.ads.googleads.v19",
    manifest={
        "UserListTypeEnum",
    },
)


class UserListTypeEnum(proto.Message):
    r"""The user list types."""

    class UserListType(proto.Enum):
        r"""Enum containing possible user list types.

        Values:
            UNSPECIFIED (0):
                Not specified.
            UNKNOWN (1):
                Used for return value only. Represents value
                unknown in this version.
            REMARKETING (2):
                UserList represented as a collection of
                conversion types.
            LOGICAL (3):
                UserList represented as a combination of
                other user lists/interests.
            EXTERNAL_REMARKETING (4):
                UserList created in the Google Ad Manager
                platform.
            RULE_BASED (5):
                UserList associated with a rule.
            SIMILAR (6):
                UserList with users similar to users of
                another UserList.
            CRM_BASED (7):
                UserList of first-party CRM data provided by
                advertiser in the form of emails or other
                formats.
            LOOKALIKE (9):
                LookalikeUserlist, composed of users similar
                to those of a configurable seed (set of
                UserLists)
        """

        UNSPECIFIED = 0
        UNKNOWN = 1
        REMARKETING = 2
        LOGICAL = 3
        EXTERNAL_REMARKETING = 4
        RULE_BASED = 5
        SIMILAR = 6
        CRM_BASED = 7
        LOOKALIKE = 9


__all__ = tuple(sorted(__protobuf__.manifest))



#!/usr/bin/env python
# Copyright 2018 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""This example adds campaign targeting criteria."""


import argparse
from typing import List
import sys

from google.ads.googleads.client import GoogleAdsClient
from google.ads.googleads.errors import GoogleAdsException
from google.ads.googleads.v22.common.types.criteria import (
    KeywordInfo,
)
from google.ads.googleads.v22.resources.types.campaign_criterion import (
    CampaignCriterion,
)
from google.ads.googleads.v22.services.services.campaign_service import (
    CampaignServiceClient,
)
from google.ads.googleads.v22.services.services.campaign_criterion_service import (
    CampaignCriterionServiceClient,
)
from google.ads.googleads.v22.services.services.geo_target_constant_service import (
    GeoTargetConstantServiceClient,
)
from google.ads.googleads.v22.services.types.campaign_criterion_service import (
    CampaignCriterionOperation,
    MutateCampaignCriteriaResponse,
)


def main(
    client: GoogleAdsClient,
    customer_id: str,
    campaign_id: str,
    keyword_text: str,
    location_id: str,
) -> None:
    campaign_criterion_service: CampaignCriterionServiceClient = (
        client.get_service("CampaignCriterionService")
    )

    operations: List[CampaignCriterionOperation] = [
        create_location_op(client, customer_id, campaign_id, location_id),
        create_negative_keyword_op(
            client, customer_id, campaign_id, keyword_text
        ),
        create_proximity_op(client, customer_id, campaign_id),
    ]

    campaign_criterion_response: MutateCampaignCriteriaResponse = (
        campaign_criterion_service.mutate_campaign_criteria(
            customer_id=customer_id, operations=operations
        )
    )

    for result in campaign_criterion_response.results:
        print(f'Added campaign criterion "{result.resource_name}".')


# [START add_campaign_targeting_criteria]
def create_location_op(
    client: GoogleAdsClient,
    customer_id: str,
    campaign_id: str,
    location_id: str,
) -> CampaignCriterionOperation:
    campaign_service: CampaignServiceClient = client.get_service(
        "CampaignService"
    )
    geo_target_constant_service: GeoTargetConstantServiceClient = (
        client.get_service("GeoTargetConstantService")
    )

    # Create the campaign criterion.
    campaign_criterion_operation: CampaignCriterionOperation = client.get_type(
        "CampaignCriterionOperation"
    )
    campaign_criterion: CampaignCriterion = campaign_criterion_operation.create
    campaign_criterion.campaign = campaign_service.campaign_path(
        customer_id, campaign_id
    )

    # Besides using location_id, you can also search by location names from
    # GeoTargetConstantService.suggest_geo_target_constants() and directly
    # apply GeoTargetConstant.resource_name here. An example can be found
    # in get_geo_target_constant_by_names.py.
    campaign_criterion.location.geo_target_constant = (
        geo_target_constant_service.geo_target_constant_path(location_id)
    )

    return campaign_criterion_operation
    # [END add_campaign_targeting_criteria]


def create_negative_keyword_op(
    client: GoogleAdsClient,
    customer_id: str,
    campaign_id: str,
    keyword_text: str,
) -> CampaignCriterionOperation:
    campaign_service: CampaignServiceClient = client.get_service(
        "CampaignService"
    )

    # Create the campaign criterion.
    campaign_criterion_operation: CampaignCriterionOperation = client.get_type(
        "CampaignCriterionOperation"
    )
    campaign_criterion: CampaignCriterion = campaign_criterion_operation.create
    campaign_criterion.campaign = campaign_service.campaign_path(
        customer_id, campaign_id
    )
    campaign_criterion.negative = True
    criterion_keyword: KeywordInfo = campaign_criterion.keyword
    criterion_keyword.text = keyword_text
    criterion_keyword.match_type = client.enums.KeywordMatchTypeEnum.BROAD

    return campaign_criterion_operation


# [START add_campaign_targeting_criteria_1]
def create_proximity_op(
    client: GoogleAdsClient, customer_id: str, campaign_id: str
) -> CampaignCriterionOperation:
    campaign_service: CampaignServiceClient = client.get_service(
        "CampaignService"
    )

    # Create the campaign criterion.
    campaign_criterion_operation: CampaignCriterionOperation = client.get_type(
        "CampaignCriterionOperation"
    )
    campaign_criterion: CampaignCriterion = campaign_criterion_operation.create
    campaign_criterion.campaign = campaign_service.campaign_path(
        customer_id, campaign_id
    )
    campaign_criterion.proximity.address.street_address = "38 avenue de l'Opera"
    campaign_criterion.proximity.address.city_name = "Paris"
    campaign_criterion.proximity.address.postal_code = "75002"
    campaign_criterion.proximity.address.country_code = "FR"
    campaign_criterion.proximity.radius = 10
    # Default is kilometers.
    campaign_criterion.proximity.radius_units = (
        client.enums.ProximityRadiusUnitsEnum.MILES
    )

    return campaign_criterion_operation
    # [END add_campaign_targeting_criteria_1]


if __name__ == "__main__":
    parser = argparse.ArgumentParser(
        description=(
            "Adds campaign targeting criteria for the specified "
            "campaign under the given customer ID."
        )
    )
    # The following argument(s) should be provided to run the example.
    parser.add_argument(
        "-c",
        "--customer_id",
        type=str,
        required=True,
        help="The Google Ads customer ID.",
    )
    parser.add_argument(
        "-i", "--campaign_id", type=str, required=True, help="The campaign ID."
    )
    parser.add_argument(
        "-k",
        "--keyword_text",
        type=str,
        required=True,
        help="The keyword text to be added to the campaign.",
    )
    parser.add_argument(
        "-l",
        "--location_id",
        type=str,
        required=False,
        default="21167",  # New York
        help=(
            "A location criterion ID, this field is optional. If not "
            "specified, will default to New York. For more information on "
            "determining this value, see: "
            "https://developers.google.com/google-ads/api/reference/data/geotargets"
        ),
    )
    args: argparse.Namespace = parser.parse_args()

    # GoogleAdsClient will read the google-ads.yaml configuration file in the
    # home directory if none is specified.
    googleads_client: GoogleAdsClient = GoogleAdsClient.load_from_storage(
        version="v22"
    )

    try:
        main(
            googleads_client,
            args.customer_id,
            args.campaign_id,
            args.keyword_text,
            args.location_id,
        )
    except GoogleAdsException as ex:
        print(
            f'Request with ID "{ex.request_id}" failed with status '
            f'"{ex.error.code().name}" and includes the following errors:'
        )
        for error in ex.failure.errors:
            print(f'\tError with message "{error.message}".')
            if error.location:
                for field_path_element in error.location.field_path_elements:
                    print(f"\t\tOn field: {field_path_element.field_name}")
        sys.exit(1)



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations


import proto  # type: ignore


__protobuf__ = proto.module(
    package="google.ads.googleads.v20.enums",
    marshal="google.ads.googleads.v20",
    manifest={
        "AssetSetTypeEnum",
    },
)


class AssetSetTypeEnum(proto.Message):
    r"""Container for enum describing possible types of an asset set."""

    class AssetSetType(proto.Enum):
        r"""Possible types of an asset set.

        Values:
            UNSPECIFIED (0):
                Not specified.
            UNKNOWN (1):
                Used for return value only. Represents value
                unknown in this version.
            PAGE_FEED (2):
                Page asset set.
            DYNAMIC_EDUCATION (3):
                Dynamic education asset set.
            MERCHANT_CENTER_FEED (4):
                Google Merchant Center asset set.
            DYNAMIC_REAL_ESTATE (5):
                Dynamic real estate asset set.
            DYNAMIC_CUSTOM (6):
                Dynamic custom asset set.
            DYNAMIC_HOTELS_AND_RENTALS (7):
                Dynamic hotels and rentals asset set.
            DYNAMIC_FLIGHTS (8):
                Dynamic flights asset set.
            DYNAMIC_TRAVEL (9):
                Dynamic travel asset set.
            DYNAMIC_LOCAL (10):
                Dynamic local asset set.
            DYNAMIC_JOBS (11):
                Dynamic jobs asset set.
            LOCATION_SYNC (12):
                Location sync level asset set.
            BUSINESS_PROFILE_DYNAMIC_LOCATION_GROUP (13):
                Business Profile location group asset set.
            CHAIN_DYNAMIC_LOCATION_GROUP (14):
                Chain location group asset set which can be
                used for both owned locations and affiliate
                locations.
            STATIC_LOCATION_GROUP (15):
                Static location group asset set which can be
                used for both owned locations and affiliate
                locations.
            HOTEL_PROPERTY (16):
                Hotel Property asset set which is used to
                link a hotel property feed to Performance Max
                for travel goals campaigns.
            TRAVEL_FEED (17):
                Travel Feed asset set type. Can represent
                either a Hotel feed or a Things to Do
                (activities) feed.
        """

        UNSPECIFIED = 0
        UNKNOWN = 1
        PAGE_FEED = 2
        DYNAMIC_EDUCATION = 3
        MERCHANT_CENTER_FEED = 4
        DYNAMIC_REAL_ESTATE = 5
        DYNAMIC_CUSTOM = 6
        DYNAMIC_HOTELS_AND_RENTALS = 7
        DYNAMIC_FLIGHTS = 8
        DYNAMIC_TRAVEL = 9
        DYNAMIC_LOCAL = 10
        DYNAMIC_JOBS = 11
        LOCATION_SYNC = 12
        BUSINESS_PROFILE_DYNAMIC_LOCATION_GROUP = 13
        CHAIN_DYNAMIC_LOCATION_GROUP = 14
        STATIC_LOCATION_GROUP = 15
        HOTEL_PROPERTY = 16
        TRAVEL_FEED = 17


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from google.ads.googleads.v21 import gapic_version as package_version

__version__ = package_version.__version__


from .types.accessible_bidding_strategy import AccessibleBiddingStrategy
from .types.account_budget import AccountBudget
from .types.account_budget_proposal import AccountBudgetProposal
from .types.account_link import AccountLink
from .types.account_link import ThirdPartyAppAnalyticsLinkIdentifier
from .types.ad import Ad
from .types.ad_group import AdGroup
from .types.ad_group_ad import AdGroupAd
from .types.ad_group_ad import AdGroupAdAssetAutomationSetting
from .types.ad_group_ad import AdGroupAdPolicySummary
from .types.ad_group_ad_asset_combination_view import (
    AdGroupAdAssetCombinationView,
)
from .types.ad_group_ad_asset_view import AdGroupAdAssetPolicySummary
from .types.ad_group_ad_asset_view import AdGroupAdAssetView
from .types.ad_group_ad_label import AdGroupAdLabel
from .types.ad_group_asset import AdGroupAsset
from .types.ad_group_asset_set import AdGroupAssetSet
from .types.ad_group_audience_view import AdGroupAudienceView
from .types.ad_group_bid_modifier import AdGroupBidModifier
from .types.ad_group_criterion import AdGroupCriterion
from .types.ad_group_criterion_customizer import AdGroupCriterionCustomizer
from .types.ad_group_criterion_label import AdGroupCriterionLabel
from .types.ad_group_criterion_simulation import AdGroupCriterionSimulation
from .types.ad_group_customizer import AdGroupCustomizer
from .types.ad_group_label import AdGroupLabel
from .types.ad_group_simulation import AdGroupSimulation
from .types.ad_parameter import AdParameter
from .types.ad_schedule_view import AdScheduleView
from .types.age_range_view import AgeRangeView
from .types.ai_max_search_term_ad_combination_view import (
    AiMaxSearchTermAdCombinationView,
)
from .types.android_privacy_shared_key_google_ad_group import (
    AndroidPrivacySharedKeyGoogleAdGroup,
)
from .types.android_privacy_shared_key_google_campaign import (
    AndroidPrivacySharedKeyGoogleCampaign,
)
from .types.android_privacy_shared_key_google_network_type import (
    AndroidPrivacySharedKeyGoogleNetworkType,
)
from .types.asset import Asset
from .types.asset import AssetFieldTypePolicySummary
from .types.asset import AssetPolicySummary
from .types.asset_field_type_view import AssetFieldTypeView
from .types.asset_group import AdStrengthActionItem
from .types.asset_group import AssetCoverage
from .types.asset_group import AssetGroup
from .types.asset_group_asset import AssetGroupAsset
from .types.asset_group_listing_group_filter import AssetGroupListingGroupFilter
from .types.asset_group_listing_group_filter import ListingGroupFilterDimension
from .types.asset_group_listing_group_filter import (
    ListingGroupFilterDimensionPath,
)
from .types.asset_group_product_group_view import AssetGroupProductGroupView
from .types.asset_group_signal import AssetGroupSignal
from .types.asset_group_top_combination_view import (
    AssetGroupAssetCombinationData,
)
from .types.asset_group_top_combination_view import AssetGroupTopCombinationView
from .types.asset_set import AssetSet
from .types.asset_set_asset import AssetSetAsset
from .types.asset_set_type_view import AssetSetTypeView
from .types.audience import Audience
from .types.batch_job import BatchJob
from .types.bidding_data_exclusion import BiddingDataExclusion
from .types.bidding_seasonality_adjustment import BiddingSeasonalityAdjustment
from .types.bidding_strategy import BiddingStrategy
from .types.bidding_strategy_simulation import BiddingStrategySimulation
from .types.billing_setup import BillingSetup
from .types.call_view import CallView
from .types.campaign import Campaign
from .types.campaign_aggregate_asset_view import CampaignAggregateAssetView
from .types.campaign_asset import CampaignAsset
from .types.campaign_asset_set import CampaignAssetSet
from .types.campaign_audience_view import CampaignAudienceView
from .types.campaign_bid_modifier import CampaignBidModifier
from .types.campaign_budget import CampaignBudget
from .types.campaign_conversion_goal import CampaignConversionGoal
from .types.campaign_criterion import CampaignCriterion
from .types.campaign_customizer import CampaignCustomizer
from .types.campaign_draft import CampaignDraft
from .types.campaign_group import CampaignGroup
from .types.campaign_label import CampaignLabel
from .types.campaign_lifecycle_goal import CampaignLifecycleGoal
from .types.campaign_lifecycle_goal import CustomerAcquisitionGoalSettings
from .types.campaign_search_term_insight import CampaignSearchTermInsight
from .types.campaign_search_term_view import CampaignSearchTermView
from .types.campaign_shared_set import CampaignSharedSet
from .types.campaign_simulation import CampaignSimulation
from .types.carrier_constant import CarrierConstant
from .types.change_event import ChangeEvent
from .types.change_status import ChangeStatus
from .types.channel_aggregate_asset_view import ChannelAggregateAssetView
from .types.click_view import ClickView
from .types.combined_audience import CombinedAudience
from .types.content_criterion_view import ContentCriterionView
from .types.conversion_action import ConversionAction
from .types.conversion_custom_variable import ConversionCustomVariable
from .types.conversion_goal_campaign_config import ConversionGoalCampaignConfig
from .types.conversion_value_rule import ConversionValueRule
from .types.conversion_value_rule_set import ConversionValueRuleSet
from .types.currency_constant import CurrencyConstant
from .types.custom_audience import CustomAudience
from .types.custom_audience import CustomAudienceMember
from .types.custom_conversion_goal import CustomConversionGoal
from .types.custom_interest import CustomInterest
from .types.custom_interest import CustomInterestMember
from .types.customer import CallReportingSetting
from .types.customer import ConversionTrackingSetting
from .types.customer import Customer
from .types.customer import CustomerAgreementSetting
from .types.customer import GranularInsuranceStatus
from .types.customer import GranularLicenseStatus
from .types.customer import LocalServicesSettings
from .types.customer import RemarketingSetting
from .types.customer import VideoCustomer
from .types.customer_asset import CustomerAsset
from .types.customer_asset_set import CustomerAssetSet
from .types.customer_client import CustomerClient
from .types.customer_client_link import CustomerClientLink
from .types.customer_conversion_goal import CustomerConversionGoal
from .types.customer_customizer import CustomerCustomizer
from .types.customer_label import CustomerLabel
from .types.customer_lifecycle_goal import CustomerLifecycleGoal
from .types.customer_manager_link import CustomerManagerLink
from .types.customer_negative_criterion import CustomerNegativeCriterion
from .types.customer_search_term_insight import CustomerSearchTermInsight
from .types.customer_sk_ad_network_conversion_value_schema import (
    CustomerSkAdNetworkConversionValueSchema,
)
from .types.customer_user_access import CustomerUserAccess
from .types.customer_user_access_invitation import CustomerUserAccessInvitation
from .types.customizer_attribute import CustomizerAttribute
from .types.data_link import DataLink
from .types.data_link import YoutubeVideoIdentifier
from .types.detail_content_suitability_placement_view import (
    DetailContentSuitabilityPlacementView,
)
from .types.detail_placement_view import DetailPlacementView
from .types.detailed_demographic import DetailedDemographic
from .types.display_keyword_view import DisplayKeywordView
from .types.distance_view import DistanceView
from .types.domain_category import DomainCategory
from .types.dynamic_search_ads_search_term_view import (
    DynamicSearchAdsSearchTermView,
)
from .types.expanded_landing_page_view import ExpandedLandingPageView
from .types.experiment import Experiment
from .types.experiment_arm import ExperimentArm
from .types.final_url_expansion_asset_view import FinalUrlExpansionAssetView
from .types.gender_view import GenderView
from .types.geo_target_constant import GeoTargetConstant
from .types.geographic_view import GeographicView
from .types.google_ads_field import GoogleAdsField
from .types.group_content_suitability_placement_view import (
    GroupContentSuitabilityPlacementView,
)
from .types.group_placement_view import GroupPlacementView
from .types.hotel_group_view import HotelGroupView
from .types.hotel_performance_view import HotelPerformanceView
from .types.hotel_reconciliation import HotelReconciliation
from .types.income_range_view import IncomeRangeView
from .types.invoice import Invoice
from .types.keyword_plan import KeywordPlan
from .types.keyword_plan import KeywordPlanForecastPeriod
from .types.keyword_plan_ad_group import KeywordPlanAdGroup
from .types.keyword_plan_ad_group_keyword import KeywordPlanAdGroupKeyword
from .types.keyword_plan_campaign import KeywordPlanCampaign
from .types.keyword_plan_campaign import KeywordPlanGeoTarget
from .types.keyword_plan_campaign_keyword import KeywordPlanCampaignKeyword
from .types.keyword_theme_constant import KeywordThemeConstant
from .types.keyword_view import KeywordView
from .types.label import Label
from .types.landing_page_view import LandingPageView
from .types.language_constant import LanguageConstant
from .types.lead_form_submission_data import CustomLeadFormSubmissionField
from .types.lead_form_submission_data import LeadFormSubmissionData
from .types.lead_form_submission_data import LeadFormSubmissionField
from .types.life_event import LifeEvent
from .types.local_services_employee import Fellowship
from .types.local_services_employee import LocalServicesEmployee
from .types.local_services_employee import Residency
from .types.local_services_employee import UniversityDegree
from .types.local_services_lead import ContactDetails
from .types.local_services_lead import CreditDetails
from .types.local_services_lead import LocalServicesLead
from .types.local_services_lead import Note
from .types.local_services_lead_conversation import (
    LocalServicesLeadConversation,
)
from .types.local_services_lead_conversation import MessageDetails
from .types.local_services_lead_conversation import PhoneCallDetails
from .types.local_services_verification_artifact import (
    BackgroundCheckVerificationArtifact,
)
from .types.local_services_verification_artifact import (
    BusinessRegistrationCheckVerificationArtifact,
)
from .types.local_services_verification_artifact import (
    BusinessRegistrationDocument,
)
from .types.local_services_verification_artifact import (
    BusinessRegistrationNumber,
)
from .types.local_services_verification_artifact import (
    InsuranceVerificationArtifact,
)
from .types.local_services_verification_artifact import (
    LicenseVerificationArtifact,
)
from .types.local_services_verification_artifact import (
    LocalServicesVerificationArtifact,
)
from .types.location_interest_view import LocationInterestView
from .types.location_view import LocationView
from .types.managed_placement_view import ManagedPlacementView
from .types.media_file import MediaAudio
from .types.media_file import MediaBundle
from .types.media_file import MediaFile
from .types.media_file import MediaImage
from .types.media_file import MediaVideo
from .types.mobile_app_category_constant import MobileAppCategoryConstant
from .types.mobile_device_constant import MobileDeviceConstant
from .types.offline_conversion_upload_client_summary import (
    OfflineConversionAlert,
)
from .types.offline_conversion_upload_client_summary import (
    OfflineConversionError,
)
from .types.offline_conversion_upload_client_summary import (
    OfflineConversionSummary,
)
from .types.offline_conversion_upload_client_summary import (
    OfflineConversionUploadClientSummary,
)
from .types.offline_conversion_upload_conversion_action_summary import (
    OfflineConversionUploadConversionActionSummary,
)
from .types.offline_user_data_job import OfflineUserDataJob
from .types.offline_user_data_job import OfflineUserDataJobMetadata
from .types.operating_system_version_constant import (
    OperatingSystemVersionConstant,
)
from .types.paid_organic_search_term_view import PaidOrganicSearchTermView
from .types.parental_status_view import ParentalStatusView
from .types.payments_account import PaymentsAccount
from .types.per_store_view import PerStoreView
from .types.performance_max_placement_view import PerformanceMaxPlacementView
from .types.product_category_constant import ProductCategoryConstant
from .types.product_group_view import ProductGroupView
from .types.product_link import AdvertisingPartnerIdentifier
from .types.product_link import DataPartnerIdentifier
from .types.product_link import GoogleAdsIdentifier
from .types.product_link import MerchantCenterIdentifier
from .types.product_link import ProductLink
from .types.product_link_invitation import (
    AdvertisingPartnerLinkInvitationIdentifier,
)
from .types.product_link_invitation import HotelCenterLinkInvitationIdentifier
from .types.product_link_invitation import (
    MerchantCenterLinkInvitationIdentifier,
)
from .types.product_link_invitation import ProductLinkInvitation
from .types.qualifying_question import QualifyingQuestion
from .types.recommendation import Recommendation
from .types.recommendation_subscription import RecommendationSubscription
from .types.remarketing_action import RemarketingAction
from .types.search_term_view import SearchTermView
from .types.shared_criterion import SharedCriterion
from .types.shared_set import SharedSet
from .types.shopping_performance_view import ShoppingPerformanceView
from .types.shopping_product import ShoppingProduct
from .types.smart_campaign_search_term_view import SmartCampaignSearchTermView
from .types.smart_campaign_setting import SmartCampaignSetting
from .types.third_party_app_analytics_link import ThirdPartyAppAnalyticsLink
from .types.topic_constant import TopicConstant
from .types.topic_view import TopicView
from .types.travel_activity_group_view import TravelActivityGroupView
from .types.travel_activity_performance_view import (
    TravelActivityPerformanceView,
)
from .types.user_interest import UserInterest
from .types.user_list import UserList
from .types.user_list_customer_type import UserListCustomerType
from .types.user_location_view import UserLocationView
from .types.video import Video
from .types.webpage_view import WebpageView

__all__ = (
    "AccessibleBiddingStrategy",
    "AccountBudget",
    "AccountBudgetProposal",
    "AccountLink",
    "Ad",
    "AdGroup",
    "AdGroupAd",
    "AdGroupAdAssetAutomationSetting",
    "AdGroupAdAssetCombinationView",
    "AdGroupAdAssetPolicySummary",
    "AdGroupAdAssetView",
    "AdGroupAdLabel",
    "AdGroupAdPolicySummary",
    "AdGroupAsset",
    "AdGroupAssetSet",
    "AdGroupAudienceView",
    "AdGroupBidModifier",
    "AdGroupCriterion",
    "AdGroupCriterionCustomizer",
    "AdGroupCriterionLabel",
    "AdGroupCriterionSimulation",
    "AdGroupCustomizer",
    "AdGroupLabel",
    "AdGroupSimulation",
    "AdParameter",
    "AdScheduleView",
    "AdStrengthActionItem",
    "AdvertisingPartnerIdentifier",
    "AdvertisingPartnerLinkInvitationIdentifier",
    "AgeRangeView",
    "AiMaxSearchTermAdCombinationView",
    "AndroidPrivacySharedKeyGoogleAdGroup",
    "AndroidPrivacySharedKeyGoogleCampaign",
    "AndroidPrivacySharedKeyGoogleNetworkType",
    "Asset",
    "AssetCoverage",
    "AssetFieldTypePolicySummary",
    "AssetFieldTypeView",
    "AssetGroup",
    "AssetGroupAsset",
    "AssetGroupAssetCombinationData",
    "AssetGroupListingGroupFilter",
    "AssetGroupProductGroupView",
    "AssetGroupSignal",
    "AssetGroupTopCombinationView",
    "AssetPolicySummary",
    "AssetSet",
    "AssetSetAsset",
    "AssetSetTypeView",
    "Audience",
    "BackgroundCheckVerificationArtifact",
    "BatchJob",
    "BiddingDataExclusion",
    "BiddingSeasonalityAdjustment",
    "BiddingStrategy",
    "BiddingStrategySimulation",
    "BillingSetup",
    "BusinessRegistrationCheckVerificationArtifact",
    "BusinessRegistrationDocument",
    "BusinessRegistrationNumber",
    "CallReportingSetting",
    "CallView",
    "Campaign",
    "CampaignAggregateAssetView",
    "CampaignAsset",
    "CampaignAssetSet",
    "CampaignAudienceView",
    "CampaignBidModifier",
    "CampaignBudget",
    "CampaignConversionGoal",
    "CampaignCriterion",
    "CampaignCustomizer",
    "CampaignDraft",
    "CampaignGroup",
    "CampaignLabel",
    "CampaignLifecycleGoal",
    "CampaignSearchTermInsight",
    "CampaignSearchTermView",
    "CampaignSharedSet",
    "CampaignSimulation",
    "CarrierConstant",
    "ChangeEvent",
    "ChangeStatus",
    "ChannelAggregateAssetView",
    "ClickView",
    "CombinedAudience",
    "ContactDetails",
    "ContentCriterionView",
    "ConversionAction",
    "ConversionCustomVariable",
    "ConversionGoalCampaignConfig",
    "ConversionTrackingSetting",
    "ConversionValueRule",
    "ConversionValueRuleSet",
    "CreditDetails",
    "CurrencyConstant",
    "CustomAudience",
    "CustomAudienceMember",
    "CustomConversionGoal",
    "CustomInterest",
    "CustomInterestMember",
    "CustomLeadFormSubmissionField",
    "Customer",
    "CustomerAcquisitionGoalSettings",
    "CustomerAgreementSetting",
    "CustomerAsset",
    "CustomerAssetSet",
    "CustomerClient",
    "CustomerClientLink",
    "CustomerConversionGoal",
    "CustomerCustomizer",
    "CustomerLabel",
    "CustomerLifecycleGoal",
    "CustomerManagerLink",
    "CustomerNegativeCriterion",
    "CustomerSearchTermInsight",
    "CustomerSkAdNetworkConversionValueSchema",
    "CustomerUserAccess",
    "CustomerUserAccessInvitation",
    "CustomizerAttribute",
    "DataLink",
    "DataPartnerIdentifier",
    "DetailContentSuitabilityPlacementView",
    "DetailPlacementView",
    "DetailedDemographic",
    "DisplayKeywordView",
    "DistanceView",
    "DomainCategory",
    "DynamicSearchAdsSearchTermView",
    "ExpandedLandingPageView",
    "Experiment",
    "ExperimentArm",
    "Fellowship",
    "FinalUrlExpansionAssetView",
    "GenderView",
    "GeoTargetConstant",
    "GeographicView",
    "GoogleAdsField",
    "GoogleAdsIdentifier",
    "GranularInsuranceStatus",
    "GranularLicenseStatus",
    "GroupContentSuitabilityPlacementView",
    "GroupPlacementView",
    "HotelCenterLinkInvitationIdentifier",
    "HotelGroupView",
    "HotelPerformanceView",
    "HotelReconciliation",
    "IncomeRangeView",
    "InsuranceVerificationArtifact",
    "Invoice",
    "KeywordPlan",
    "KeywordPlanAdGroup",
    "KeywordPlanAdGroupKeyword",
    "KeywordPlanCampaign",
    "KeywordPlanCampaignKeyword",
    "KeywordPlanForecastPeriod",
    "KeywordPlanGeoTarget",
    "KeywordThemeConstant",
    "KeywordView",
    "Label",
    "LandingPageView",
    "LanguageConstant",
    "LeadFormSubmissionData",
    "LeadFormSubmissionField",
    "LicenseVerificationArtifact",
    "LifeEvent",
    "ListingGroupFilterDimension",
    "ListingGroupFilterDimensionPath",
    "LocalServicesEmployee",
    "LocalServicesLead",
    "LocalServicesLeadConversation",
    "LocalServicesSettings",
    "LocalServicesVerificationArtifact",
    "LocationInterestView",
    "LocationView",
    "ManagedPlacementView",
    "MediaAudio",
    "MediaBundle",
    "MediaFile",
    "MediaImage",
    "MediaVideo",
    "MerchantCenterIdentifier",
    "MerchantCenterLinkInvitationIdentifier",
    "MessageDetails",
    "MobileAppCategoryConstant",
    "MobileDeviceConstant",
    "Note",
    "OfflineConversionAlert",
    "OfflineConversionError",
    "OfflineConversionSummary",
    "OfflineConversionUploadClientSummary",
    "OfflineConversionUploadConversionActionSummary",
    "OfflineUserDataJob",
    "OfflineUserDataJobMetadata",
    "OperatingSystemVersionConstant",
    "PaidOrganicSearchTermView",
    "ParentalStatusView",
    "PaymentsAccount",
    "PerStoreView",
    "PerformanceMaxPlacementView",
    "PhoneCallDetails",
    "ProductCategoryConstant",
    "ProductGroupView",
    "ProductLink",
    "ProductLinkInvitation",
    "QualifyingQuestion",
    "Recommendation",
    "RecommendationSubscription",
    "RemarketingAction",
    "RemarketingSetting",
    "Residency",
    "SearchTermView",
    "SharedCriterion",
    "SharedSet",
    "ShoppingPerformanceView",
    "ShoppingProduct",
    "SmartCampaignSearchTermView",
    "SmartCampaignSetting",
    "ThirdPartyAppAnalyticsLink",
    "ThirdPartyAppAnalyticsLinkIdentifier",
    "TopicConstant",
    "TopicView",
    "TravelActivityGroupView",
    "TravelActivityPerformanceView",
    "UniversityDegree",
    "UserInterest",
    "UserList",
    "UserListCustomerType",
    "UserLocationView",
    "Video",
    "VideoCustomer",
    "WebpageView",
    "YoutubeVideoIdentifier",
)



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations


import proto  # type: ignore

from google.ads.googleads.v22.enums.types import (
    recommendation_subscription_status,
)
from google.ads.googleads.v22.enums.types import recommendation_type


__protobuf__ = proto.module(
    package="google.ads.googleads.v22.resources",
    marshal="google.ads.googleads.v22",
    manifest={
        "RecommendationSubscription",
    },
)


class RecommendationSubscription(proto.Message):
    r"""Recommendation Subscription resource

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        resource_name (str):
            Immutable. The resource name of the recommendation
            subscription.

            ``customers/{customer_id}/recommendationSubscriptions/{recommendation_type}``
        type_ (google.ads.googleads.v22.enums.types.RecommendationTypeEnum.RecommendationType):
            Required. Immutable. The type of
            recommendation subscribed to.
        create_date_time (str):
            Output only. Time in seconds when the
            subscription was first created. The datetime is
            in the customer's time zone and in "yyyy-MM-dd
            HH:mm:ss" format.

            This field is a member of `oneof`_ ``_create_date_time``.
        modify_date_time (str):
            Output only. Contains the time in
            microseconds, when the Recommendation
            Subscription was last updated. The datetime is
            in the customer's time zone and in "yyyy-MM-dd
            HH:mm:ss.ssssss" format.

            This field is a member of `oneof`_ ``_modify_date_time``.
        status (google.ads.googleads.v22.enums.types.RecommendationSubscriptionStatusEnum.RecommendationSubscriptionStatus):
            Required. Status of the subscription, either
            enabled or paused.

            This field is a member of `oneof`_ ``_status``.
    """

    resource_name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    type_: recommendation_type.RecommendationTypeEnum.RecommendationType = (
        proto.Field(
            proto.ENUM,
            number=2,
            enum=recommendation_type.RecommendationTypeEnum.RecommendationType,
        )
    )
    create_date_time: str = proto.Field(
        proto.STRING,
        number=3,
        optional=True,
    )
    modify_date_time: str = proto.Field(
        proto.STRING,
        number=4,
        optional=True,
    )
    status: (
        recommendation_subscription_status.RecommendationSubscriptionStatusEnum.RecommendationSubscriptionStatus
    ) = proto.Field(
        proto.ENUM,
        number=5,
        optional=True,
        enum=recommendation_subscription_status.RecommendationSubscriptionStatusEnum.RecommendationSubscriptionStatus,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations


import proto  # type: ignore


__protobuf__ = proto.module(
    package="google.ads.googleads.v21.errors",
    marshal="google.ads.googleads.v21",
    manifest={
        "ConversionAdjustmentUploadErrorEnum",
    },
)


class ConversionAdjustmentUploadErrorEnum(proto.Message):
    r"""Container for enum describing possible conversion adjustment
    upload errors.

    """

    class ConversionAdjustmentUploadError(proto.Enum):
        r"""Enum describing possible conversion adjustment upload errors.

        Values:
            UNSPECIFIED (0):
                Not specified.
            UNKNOWN (1):
                Used for return value only. Represents value
                unknown in this version.
            TOO_RECENT_CONVERSION_ACTION (2):
                Can't import events to a conversion action
                that was just created. Try importing again in 6
                hours.
            CONVERSION_ALREADY_RETRACTED (4):
                The conversion was already retracted. This
                adjustment was not processed.
            CONVERSION_NOT_FOUND (5):
                The conversion for this conversion action and
                conversion identifier can't be found. Make sure
                your conversion identifiers are associated with
                the correct conversion action and try again.
            CONVERSION_EXPIRED (6):
                Adjustment can't be made to a conversion that
                occurred more than 54 days ago.
            ADJUSTMENT_PRECEDES_CONVERSION (7):
                Adjustment has an ``adjustment_date_time`` that occurred
                before the associated conversion. Make sure your
                ``adjustment_date_time`` is correct and try again.
            MORE_RECENT_RESTATEMENT_FOUND (8):
                More recent adjustment ``adjustment_date_time`` has already
                been reported for the associated conversion. Make sure your
                adjustment ``adjustment_date_time`` is correct and try
                again.
            TOO_RECENT_CONVERSION (9):
                Adjustment can't be recorded because the
                conversion occurred too recently. Try adjusting
                a conversion that occurred at least 24 hours
                ago.
            CANNOT_RESTATE_CONVERSION_ACTION_THAT_ALWAYS_USES_DEFAULT_CONVERSION_VALUE (10):
                Can't make an adjustment to a conversion that
                is set up to use the default value. Check your
                conversion action value setting and try again.
            TOO_MANY_ADJUSTMENTS_IN_REQUEST (11):
                Try uploading fewer than 2001 adjustments in
                a single API request.
            TOO_MANY_ADJUSTMENTS (12):
                The conversion has already been adjusted the
                maximum number of times. Make sure you're only
                making necessary adjustment to existing
                conversion.
            RESTATEMENT_ALREADY_EXISTS (13):
                The conversion has prior a restatement with the same
                ``adjustment_date_time``. Make sure your adjustment has the
                correct and unique ``adjustment_date_time`` and try again.
            DUPLICATE_ADJUSTMENT_IN_REQUEST (14):
                Imported adjustment has a duplicate conversion adjustment
                with same ``adjustment_date_time``. Make sure your
                adjustment has the correct ``adjustment_date_time`` and try
                again.
            CUSTOMER_NOT_ACCEPTED_CUSTOMER_DATA_TERMS (15):
                Make sure you agree to the customer data
                processing terms in conversion settings and try
                again.
            CONVERSION_ACTION_NOT_ELIGIBLE_FOR_ENHANCEMENT (16):
                Can't use enhanced conversions with the
                specified conversion action.
            INVALID_USER_IDENTIFIER (17):
                Make sure you hash user provided data using
                SHA-256 and ensure you are normalizing according
                to the guidelines.
            UNSUPPORTED_USER_IDENTIFIER (18):
                Use user provided data such as emails or
                phone numbers hashed using SHA-256 and try
                again.
            GCLID_DATE_TIME_PAIR_AND_ORDER_ID_BOTH_SET (20):
                Cannot set both gclid_date_time_pair and order_id. Use only
                1 type and try again.
            CONVERSION_ALREADY_ENHANCED (21):
                Conversion already has enhancements with the
                same Order ID and conversion action. Make sure
                your data is correctly configured and try again.
            DUPLICATE_ENHANCEMENT_IN_REQUEST (22):
                Multiple enhancements have the same
                conversion action and Order ID.  Make sure your
                data is correctly configured and try again.
            CUSTOMER_DATA_POLICY_PROHIBITS_ENHANCEMENT (23):
                Enhanced conversions can't be used for this
                account because of Google customer data
                policies. Contact your Google representative.
            MISSING_ORDER_ID_FOR_WEBPAGE (24):
                Adjustment for website conversion requires
                Order ID (ie, transaction ID). Make sure your
                website tags capture Order IDs and you send the
                same Order IDs with your adjustment.
            ORDER_ID_CONTAINS_PII (25):
                Can't use adjustment with Order IDs
                containing personally-identifiable information
                (PII).
            INVALID_JOB_ID (26):
                The provided job id in the request is not within the allowed
                range. A job ID must be a positive integer in the range [1,
                2^31).
            NO_CONVERSION_ACTION_FOUND (27):
                The conversion action specified in the
                adjustment request cannot be found. Make sure
                it's available in this account.
            INVALID_CONVERSION_ACTION_TYPE (28):
                The type of the conversion action specified in the
                adjustment request isn't supported for uploading
                adjustments. A conversion adjustment of type ``RETRACTION``
                or ``RESTATEMENT`` is only permitted for conversion actions
                of type ``SALESFORCE``, ``UPLOAD_CLICK`` or ``WEBPAGE``. A
                conversion adjustment of type ``ENHANCEMENT`` is only
                permitted for conversion actions of type ``WEBPAGE``.
        """

        UNSPECIFIED = 0
        UNKNOWN = 1
        TOO_RECENT_CONVERSION_ACTION = 2
        CONVERSION_ALREADY_RETRACTED = 4
        CONVERSION_NOT_FOUND = 5
        CONVERSION_EXPIRED = 6
        ADJUSTMENT_PRECEDES_CONVERSION = 7
        MORE_RECENT_RESTATEMENT_FOUND = 8
        TOO_RECENT_CONVERSION = 9
        CANNOT_RESTATE_CONVERSION_ACTION_THAT_ALWAYS_USES_DEFAULT_CONVERSION_VALUE = (
            10
        )
        TOO_MANY_ADJUSTMENTS_IN_REQUEST = 11
        TOO_MANY_ADJUSTMENTS = 12
        RESTATEMENT_ALREADY_EXISTS = 13
        DUPLICATE_ADJUSTMENT_IN_REQUEST = 14
        CUSTOMER_NOT_ACCEPTED_CUSTOMER_DATA_TERMS = 15
        CONVERSION_ACTION_NOT_ELIGIBLE_FOR_ENHANCEMENT = 16
        INVALID_USER_IDENTIFIER = 17
        UNSUPPORTED_USER_IDENTIFIER = 18
        GCLID_DATE_TIME_PAIR_AND_ORDER_ID_BOTH_SET = 20
        CONVERSION_ALREADY_ENHANCED = 21
        DUPLICATE_ENHANCEMENT_IN_REQUEST = 22
        CUSTOMER_DATA_POLICY_PROHIBITS_ENHANCEMENT = 23
        MISSING_ORDER_ID_FOR_WEBPAGE = 24
        ORDER_ID_CONTAINS_PII = 25
        INVALID_JOB_ID = 26
        NO_CONVERSION_ACTION_FOUND = 27
        INVALID_CONVERSION_ACTION_TYPE = 28


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations


import proto  # type: ignore


__protobuf__ = proto.module(
    package="google.ads.googleads.v22.errors",
    marshal="google.ads.googleads.v22",
    manifest={
        "ConversionValueRuleErrorEnum",
    },
)


class ConversionValueRuleErrorEnum(proto.Message):
    r"""Container for enum describing possible conversion value rule
    errors.

    """

    class ConversionValueRuleError(proto.Enum):
        r"""Enum describing possible conversion value rule errors.

        Values:
            UNSPECIFIED (0):
                Enum unspecified.
            UNKNOWN (1):
                The received error code is not known in this
                version.
            INVALID_GEO_TARGET_CONSTANT (2):
                The value rule's geo location condition
                contains invalid geo target constant(s), for
                example, there's no matching geo target.
            CONFLICTING_INCLUDED_AND_EXCLUDED_GEO_TARGET (3):
                The value rule's geo location condition
                contains conflicting included and excluded geo
                targets. Specifically, some of the excluded geo
                target(s) are the same as or contain some of the
                included geo target(s). For example, the geo
                location condition includes California but
                excludes U.S.
            CONFLICTING_CONDITIONS (4):
                User specified conflicting conditions for two
                value rules in the same value rule set.
            CANNOT_REMOVE_IF_INCLUDED_IN_VALUE_RULE_SET (5):
                The value rule cannot be removed because it's
                still included in some value rule set.
            CONDITION_NOT_ALLOWED (6):
                The value rule contains a condition that's
                not allowed by the value rule set including this
                value rule.
            FIELD_MUST_BE_UNSET (7):
                The value rule contains a field that should
                be unset.
            CANNOT_PAUSE_UNLESS_VALUE_RULE_SET_IS_PAUSED (8):
                Pausing the value rule requires pausing the
                value rule set because the value rule is (one
                of) the last enabled in the value rule set.
            UNTARGETABLE_GEO_TARGET (9):
                The value rule's geo location condition
                contains untargetable geo target constant(s).
            INVALID_AUDIENCE_USER_LIST (10):
                The value rule's audience condition contains
                invalid user list(s). In another word, there's
                no matching user list.
            INACCESSIBLE_USER_LIST (11):
                The value rule's audience condition contains
                inaccessible user list(s).
            INVALID_AUDIENCE_USER_INTEREST (12):
                The value rule's audience condition contains invalid
                user_interest(s). This might be because there is no matching
                user interest, or the user interest is not visible.
            CANNOT_ADD_RULE_WITH_STATUS_REMOVED (13):
                When a value rule is created, it shouldn't
                have REMOVED status.
            NO_DAY_OF_WEEK_SELECTED (14):
                The value rule's itinerary condition contains
                invalid travel start day, it contains no day of
                week.
        """

        UNSPECIFIED = 0
        UNKNOWN = 1
        INVALID_GEO_TARGET_CONSTANT = 2
        CONFLICTING_INCLUDED_AND_EXCLUDED_GEO_TARGET = 3
        CONFLICTING_CONDITIONS = 4
        CANNOT_REMOVE_IF_INCLUDED_IN_VALUE_RULE_SET = 5
        CONDITION_NOT_ALLOWED = 6
        FIELD_MUST_BE_UNSET = 7
        CANNOT_PAUSE_UNLESS_VALUE_RULE_SET_IS_PAUSED = 8
        UNTARGETABLE_GEO_TARGET = 9
        INVALID_AUDIENCE_USER_LIST = 10
        INACCESSIBLE_USER_LIST = 11
        INVALID_AUDIENCE_USER_INTEREST = 12
        CANNOT_ADD_RULE_WITH_STATUS_REMOVED = 13
        NO_DAY_OF_WEEK_SELECTED = 14


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations


import proto  # type: ignore


__protobuf__ = proto.module(
    package="google.ads.googleads.v22.enums",
    marshal="google.ads.googleads.v22",
    manifest={
        "HotelRateTypeEnum",
    },
)


class HotelRateTypeEnum(proto.Message):
    r"""Container for enum describing possible hotel rate types."""

    class HotelRateType(proto.Enum):
        r"""Enum describing possible hotel rate types.

        Values:
            UNSPECIFIED (0):
                Not specified.
            UNKNOWN (1):
                The value is unknown in this version.
            UNAVAILABLE (2):
                Rate type information is unavailable.
            PUBLIC_RATE (3):
                Rates available to everyone.
            QUALIFIED_RATE (4):
                A membership program rate is available and
                satisfies basic requirements like having a
                public rate available. UI treatment will
                strikethrough the public rate and indicate that
                a discount is available to the user. For more on
                Qualified Rates, visit
                https://developers.google.com/hotels/hotel-ads/dev-guide/qualified-rates
            PRIVATE_RATE (5):
                Rates available to users that satisfy some
                eligibility criteria, for example, all signed-in
                users, 20% of mobile users, all mobile users in
                Canada, etc.
        """

        UNSPECIFIED = 0
        UNKNOWN = 1
        UNAVAILABLE = 2
        PUBLIC_RATE = 3
        QUALIFIED_RATE = 4
        PRIVATE_RATE = 5


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations


import proto  # type: ignore


__protobuf__ = proto.module(
    package="google.ads.googleads.v20.common",
    marshal="google.ads.googleads.v20",
    manifest={
        "TextLabel",
    },
)


class TextLabel(proto.Message):
    r"""A type of label displaying text on a colored background.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        background_color (str):
            Background color of the label in HEX format. This string
            must match the regular expression
            '^#([a-fA-F0-9]{6}|[a-fA-F0-9]{3})$'. Note: The background
            color may not be visible for manager accounts.

            This field is a member of `oneof`_ ``_background_color``.
        description (str):
            A short description of the label. The length
            must be no more than 200 characters.

            This field is a member of `oneof`_ ``_description``.
    """

    background_color: str = proto.Field(
        proto.STRING,
        number=3,
        optional=True,
    )
    description: str = proto.Field(
        proto.STRING,
        number=4,
        optional=True,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations


import proto  # type: ignore


__protobuf__ = proto.module(
    package="google.ads.googleads.v22.resources",
    marshal="google.ads.googleads.v22",
    manifest={
        "SmartCampaignSetting",
    },
)


class SmartCampaignSetting(proto.Message):
    r"""Settings for configuring Smart campaigns.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        resource_name (str):
            Immutable. The resource name of the Smart campaign setting.
            Smart campaign setting resource names have the form:

            ``customers/{customer_id}/smartCampaignSettings/{campaign_id}``
        campaign (str):
            Output only. The campaign to which these
            settings apply.
        phone_number (google.ads.googleads.v22.resources.types.SmartCampaignSetting.PhoneNumber):
            Phone number and country code.
        advertising_language_code (str):
            The language code to advertise in from the set of [supported
            language codes]
            (https://developers.google.com/google-ads/api/reference/data/codes-formats#languages).
        final_url (str):
            The user-provided landing page URL for this
            Campaign.

            This field is a member of `oneof`_ ``landing_page``.
        ad_optimized_business_profile_setting (google.ads.googleads.v22.resources.types.SmartCampaignSetting.AdOptimizedBusinessProfileSetting):
            Settings for configuring a business profile
            optimized for ads as this campaign's landing
            page.  This campaign must be linked to a
            business profile to use this option.  For more
            information on this feature, consult
            https://support.google.com/google-ads/answer/9827068.

            This field is a member of `oneof`_ ``landing_page``.
        business_name (str):
            The name of the business.

            This field is a member of `oneof`_ ``business_setting``.
        business_profile_location (str):
            The resource name of a Business Profile location. Business
            Profile location resource names can be fetched through the
            Business Profile API and adhere to the following format:
            ``locations/{locationId}``.

            See the [Business Profile API]
            (https://developers.google.com/my-business/reference/businessinformation/rest/v1/accounts.locations)
            for additional details.

            This field is a member of `oneof`_ ``business_setting``.
    """

    class PhoneNumber(proto.Message):
        r"""Phone number and country code in smart campaign settings.

        .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

        Attributes:
            phone_number (str):
                Phone number of the smart campaign.

                This field is a member of `oneof`_ ``_phone_number``.
            country_code (str):
                Upper-case, two-letter country code as
                defined by ISO-3166.

                This field is a member of `oneof`_ ``_country_code``.
        """

        phone_number: str = proto.Field(
            proto.STRING,
            number=1,
            optional=True,
        )
        country_code: str = proto.Field(
            proto.STRING,
            number=2,
            optional=True,
        )

    class AdOptimizedBusinessProfileSetting(proto.Message):
        r"""Settings for configuring a business profile optimized for ads
        as this campaign's landing page.


        .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

        Attributes:
            include_lead_form (bool):
                Enabling a lead form on your business profile
                enables prospective customers to contact your
                business by filling out a simple form, and
                you'll receive their information through email.

                This field is a member of `oneof`_ ``_include_lead_form``.
        """

        include_lead_form: bool = proto.Field(
            proto.BOOL,
            number=1,
            optional=True,
        )

    resource_name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    campaign: str = proto.Field(
        proto.STRING,
        number=2,
    )
    phone_number: PhoneNumber = proto.Field(
        proto.MESSAGE,
        number=3,
        message=PhoneNumber,
    )
    advertising_language_code: str = proto.Field(
        proto.STRING,
        number=7,
    )
    final_url: str = proto.Field(
        proto.STRING,
        number=8,
        oneof="landing_page",
    )
    ad_optimized_business_profile_setting: AdOptimizedBusinessProfileSetting = (
        proto.Field(
            proto.MESSAGE,
            number=9,
            oneof="landing_page",
            message=AdOptimizedBusinessProfileSetting,
        )
    )
    business_name: str = proto.Field(
        proto.STRING,
        number=5,
        oneof="business_setting",
    )
    business_profile_location: str = proto.Field(
        proto.STRING,
        number=10,
        oneof="business_setting",
    )


__all__ = tuple(sorted(__protobuf__.manifest))
